@@ -1,4 +1,5 @@
 #include <bil/algo/bil_cedt.h>
+#include <bil/algo/bil_compass_edge_detector.h>
 #include <bil/algo/bil_color_conversions.h>
 #include <bil/algo/bil_detect_ridges.h>
 #include <bil/algo/bil_edge_indicator.h>
@@ -7,6 +8,7 @@
 #include <bil/algo/bil_finite_differences.h>
 #include <bil/algo/bil_finite_second_differences.h>
 #include <bil/algo/bil_harr_wavelet_transform.h>
+#include <bil/algo/bil_nms.h>
 #include <bil/algo/bil_perform_tensor_decomposition.h>
 #include <bil/algo/bil_roi_mask.h>
 #include <bil/algo/bil_scale_image.h>
