@@ -1,5 +1,7 @@
 #include <bsta/algo/bsta_adaptive_updater.h>
 #include <bsta/algo/bsta_bayes_functor.h>
+#include <bsta/algo/bsta_beta_updater.h>
+#include <bsta/algo/bsta_fit_gaussian.h>
 #include <bsta/algo/bsta_fit_weibull.h>
 #include <bsta/algo/bsta_gaussian_stats.h>
 #include <bsta/algo/bsta_gaussian_updater.h>
@@ -8,5 +10,6 @@
 #include <bsta/algo/bsta_parzen_updater.h>
 #include <bsta/algo/bsta_sample_set.h>
 #include <bsta/algo/bsta_truth_updater.h>
+#include <bsta/algo/bsta_von_mises_updater.h>
 
 int main() { return 0; }
