@@ -5,15 +5,19 @@ DECLARE( test_gaussian_indep );
 DECLARE( test_gaussian_sphere );
 DECLARE( test_parzen_sphere );
 DECLARE( test_weibull );
+DECLARE( test_von_mises );
 DECLARE( test_mixture );
 DECLARE( test_bsta_histogram );
 DECLARE( test_k_medoid );
 DECLARE( test_otsu_threshold );
 DECLARE( test_sampler );
+DECLARE( test_beta );
+DECLARE( test_kent );
 
 void
 register_tests()
 {
+  REGISTER( test_von_mises );
   REGISTER( test_gaussian_full );
   REGISTER( test_gaussian_indep );
   REGISTER( test_gaussian_sphere );
@@ -24,6 +28,8 @@ register_tests()
   REGISTER( test_k_medoid );
   REGISTER( test_otsu_threshold );
   REGISTER( test_sampler );
+  REGISTER( test_beta );
+  REGISTER( test_kent );
 }
 
 DEFINE_MAIN;
