@@ -255,6 +255,11 @@ void bwm_popup_menu::get_menu(vgui_menu &menu)
       new vgui_command_simple<bwm_tableau_cam>(cam_tab,
       &bwm_tableau_cam::geo_position_vertex));
 
+    mesh_submenu.separator();
+    mesh_submenu.add( "Local Position of Selected Vertex",
+      new vgui_command_simple<bwm_tableau_cam>(cam_tab,
+      &bwm_tableau_cam::local_position_vertex));
+
     // 3D Delete submenu
     vgui_menu del_menu;
     del_menu.add( "Delete Selected",
@@ -341,7 +346,8 @@ void bwm_popup_menu::get_menu(vgui_menu &menu)
       lvcs_submenu.add( "Define LVCS",
         new vgui_command_simple<bwm_tableau_rat_cam>(rat_cam_tab,
         &bwm_tableau_rat_cam::define_lvcs));
-      //lvcs_submenu.add( "Convert File to LVCS", new bwm_convert_to_lvcs_command(this));
+      lvcs_submenu.add( "Adjust Camera to World Point", new vgui_command_simple<bwm_tableau_rat_cam>(rat_cam_tab,
+        &bwm_tableau_rat_cam::adjust_camera_offset));
       lvcs_submenu.separator();
       lvcs_submenu.add( "Adjust Camera To LVCS",
         new vgui_command_simple<bwm_tableau_rat_cam>(rat_cam_tab,
@@ -378,6 +384,12 @@ void bwm_popup_menu::get_menu(vgui_menu &menu)
 
     video_submenu.add( "Previous Frame",
       new vgui_command_simple<bwm_tableau_video>(video_tab,&bwm_tableau_video::previous_frame));
+
+    video_submenu.separator();
+
+    video_submenu.add( "Save as Image List",
+      new vgui_command_simple<bwm_tableau_video>(video_tab,&bwm_tableau_video::save_as_image_list));
+
     menu.add("Video", video_submenu);
     menu.separator();
 
@@ -429,11 +441,18 @@ void bwm_popup_menu::get_menu(vgui_menu &menu)
     video_corr_submenu.add( "Extract World Plane",
                        new vgui_command_simple<bwm_tableau_video>(video_tab,
                        &bwm_tableau_video::extract_world_plane));
+
     video_corr_submenu.separator();
 
     video_corr_submenu.add( "Extract Neigborhoods",
                        new vgui_command_simple<bwm_tableau_video>(video_tab,
                        &bwm_tableau_video::extract_neighborhoods));
+
+    video_corr_submenu.separator();
+
+    video_corr_submenu.add( "Extract Histograms",
+                       new vgui_command_simple<bwm_tableau_video>(video_tab,
+                       &bwm_tableau_video::extract_histograms));
     menu.add("Video Correspondence", video_corr_submenu);
   }
 }
