@@ -28,6 +28,8 @@ class bwm_tableau_video : public bwm_tableau_cam
   void play();
   void stop();
   void pause();
+  void save_as_image_list();
+
   //correspondence actions
   void add_match();
   void remove_selected_corr_match();
@@ -40,6 +42,7 @@ class bwm_tableau_video : public bwm_tableau_cam
   void toggle_world_pt_display();
   void extract_world_plane();
   void extract_neighborhoods();
+  void extract_histograms();
   void set_corrs(vcl_vector<bwm_video_corr_sptr> const& corrs) { my_observer_->set_corrs(corrs); }
 protected:
   bwm_observer_video* my_observer_;
