@@ -11,7 +11,12 @@ DECLARE_FUNC_CONS(vpgl_load_rational_camera_process);
 DECLARE_FUNC_CONS(vpgl_load_rational_camera_nitf_process);
 DECLARE_FUNC_CONS(vpgl_load_perspective_camera_process);
 DECLARE_FUNC_CONS(vpgl_save_perspective_camera_process);
+DECLARE_FUNC_CONS(vpgl_scale_perspective_camera_process);
 DECLARE_FUNC_CONS(vpgl_save_rational_camera_process);
 DECLARE_FUNC_CONS(vpgl_nitf_camera_coverage_process);
+DECLARE_FUNC_CONS(vpgl_create_local_rational_camera_process);
+DECLARE_FUNC_CONS(vpgl_create_local_rational_camera_nitf_process);
+DECLARE_FUNC_CONS(vpgl_projective_to_rational_camera_process);
+
 
 #endif
