@@ -6,7 +6,7 @@
 #include <vil/vil_image_view.h>
 #include <bbgm/pro/bbgm_neighborhood_functors.h>
 
-MAIN( test_neighborhood_ops )
+static void test_neighborhood_ops()
 {
   unsigned ni = 7, nj = 7;
   vil_image_view<float> p(ni,nj);
@@ -24,7 +24,8 @@ MAIN( test_neighborhood_ops )
   float er = vcl_fabs(prop_dist(3,3).mean()-2.4f);
   er += vcl_fabs(prop_dist(3,3).var()-1.11f);
   TEST_NEAR("area_distribution", er, 0, 1e-03);
-  SUMMARY();
 }
 
+TESTMAIN(test_neighborhood_ops);
+
 
