@@ -20,16 +20,18 @@ class boxm_block
 {
  public:
   boxm_block(): octree_(0) {}
-  ~boxm_block() {if (octree_) delete octree_; }
+  ~boxm_block() { if (octree_) delete octree_; }
   boxm_block(vgl_box_3d<double> bbox): bbox_(bbox), octree_(0) {}
-  boxm_block(vgl_box_3d<double> bbox, T* tree) : bbox_(bbox), octree_(tree) {}
+  boxm_block(vgl_box_3d<double> bbox, T* tree) : bbox_(bbox), octree_(tree) {octree_->set_bbox(bbox_);}
+  //: returns the number of leaf cells in the tree
+  unsigned int size();
   void init_tree(T * octree);
-  void set_tree(T * octree){octree_=octree;}
+  void set_tree(T * octree) { octree_=octree; }
   vgl_box_3d<double> bounding_box() const { return bbox_; }
-  T* get_tree(){return octree_;}
-  void delete_tree() { if (octree_) delete octree_; octree_ = 0; }
+  T* get_tree() { return octree_; }
+  void delete_tree() { delete octree_; octree_ = 0; }
   void b_read(vsl_b_istream &s);
-  void b_write(vsl_b_ostream &s);
+  void b_write(vsl_b_ostream &s, const bool save_internal_nodes_);
   static short version_no() { return 1; }
 
  private:
