@@ -6,15 +6,14 @@
 #include <vgl/vgl_point_2d.h>
 #include <vgl/vgl_vector_2d.h>
 #include <vgl/vgl_polygon.h>
-#include <vgl/vgl_plane_3d.h>
 #include <vgl/vgl_intersection.h>
 #include <vpgl/vpgl_perspective_camera.h>
-#include <vcl_cassert.h>
-#include <vcl_cmath.h>
-#include <vcl_algorithm.h>
 #include <vnl/algo/vnl_determinant.h>
 #include <vnl/algo/vnl_matrix_inverse.h>
 #include <boxm/boxm_quad_scan_iterator.h>
+#include <vcl_cassert.h>
+#include <vcl_cmath.h>
+#include <vcl_algorithm.h>
 
 bool boxm_utils::is_visible(vgl_box_3d<double> const& bbox,
                             vpgl_camera_double_sptr const& camera,
@@ -37,8 +36,6 @@ bool boxm_utils::is_visible(vgl_box_3d<double> const& bbox,
     }
   }
 
-  
-
   // make sure corners project into image bounds
   vgl_box_2d<double> cube_proj_bb;
   vgl_box_2d<double> img_bb;
@@ -106,11 +103,6 @@ boxm_utils::project_corners(vcl_vector<vgl_point_3d<double> > const& corners,
                             vpgl_camera_double_sptr camera,
                             double* xverts, double* yverts)
 {
-#if 0
-  vcl_vector<vgl_point_3d<double> > corners=corners_of_box_3d(bbox);
-  xverts= new double[8];
-  yverts= new double[8];
-#endif // 0
   for (unsigned i=0; i<corners.size(); ++i)
     camera->project(corners[i].x(), corners[i].y(), corners[i].z(), xverts[i], yverts[i]);
 }
@@ -124,7 +116,6 @@ boxm_utils::project_corners(vcl_vector<vgl_point_3d<double> > const& corners,
     if (camera->type_name().compare("vpgl_perspective_camera")==0) {
         vpgl_perspective_camera<double>* cam = static_cast<vpgl_perspective_camera<double>*>(camera.ptr());
         vgl_point_3d<double> cam_center = vgl_point_3d<double>(cam->camera_center());
-        vcl_cout<<"center cam"<<cam_center;
         for (unsigned i=0; i<corners.size(); ++i)
         {
             cam->project(corners[i].x(), corners[i].y(), corners[i].z(), xverts[i], yverts[i]);
@@ -133,10 +124,10 @@ boxm_utils::project_corners(vcl_vector<vgl_point_3d<double> > const& corners,
     }
 }
 
-void 
+void
 boxm_utils::project_point3d(vgl_point_3d<double> const& point,
                             vpgl_camera_double_sptr camera,
-                            double & xvert, double &yvert, 
+                            double & xvert, double &yvert,
                             double & vertdist)
 {
     if (camera->type_name().compare("vpgl_perspective_camera")==0) {
@@ -151,23 +142,6 @@ boxm_utils::project_point3d(vgl_point_3d<double> const& point,
 bool boxm_utils::is_face_visible(double * xverts, double *yverts,
                                  unsigned id1,unsigned id2,unsigned id3,unsigned id4)
 {
-#if 0
-  vgl_box_2d<double> face;
-  vcl_vector<vgl_point_2d<double> > vs;
-
-  assert(face.size() >= 3);
-
-  for (unsigned i=0; i<face.size(); ++i) {
-    double u,v;
-    camera->project(face[i].x(), face[i].y(), face[i].z(), u, v);
-    vs.push_back(vgl_point_2d<double>(u,v));
-  }
-
-  vgl_vector_2d<double> v0 (xverts[id2]-xverts[id1],yverts[id2]-yverts[id1]);
-  vgl_vector_2d<double> v1 (xverts[id3]-xverts[id2],yverts[id3]-yverts[id2]);
-  vgl_vector_2d<double> v1 = vs[2] - vs[1];
-  double normal = cross_product(v0,v1);
-#endif // 0
 
   double normal=(xverts[id2]-xverts[id1])*(yverts[id3]-yverts[id2])-(yverts[id2]-yverts[id1])*(xverts[id3]-xverts[id2]);
   return normal < 0;
@@ -189,7 +163,9 @@ bool boxm_utils::is_face_visible(vcl_vector<vgl_point_3d<double> > &face,
   vgl_vector_2d<double> v0 = vs[1] - vs[0];
   vgl_vector_2d<double> v1 = vs[2] - vs[1];
   double normal = cross_product<double>(v0,v1);
-  return normal < 0;
+  //if(normal>-1e-4 && normal<0.0)
+  //    vcl_cout<<"+";
+  return normal < -1e-5;
 }
 
 vcl_vector<vgl_point_2d<double> >
@@ -235,7 +211,7 @@ boxm_utils::visible_faces(vgl_box_3d<double> const& bbox, vpgl_camera_double_spt
   //  }
   //}
   //// for other cameras, use projection and normals
-  //else 
+  //else
   {
     // fix the face normals so that the vertices are the counter clokwise order
     vcl_map<boct_face_idx, vcl_vector<vgl_point_3d<double> > > faces;
@@ -293,31 +269,33 @@ boxm_utils::visible_faces(vgl_box_3d<double> const& bbox, vpgl_camera_double_spt
                           double *xverts, double *yverts)
 {
   boct_face_idx face_idx = NONE;
-  //if (camera->type_name().compare("vpgl_perspective_camera")==0) {
-  //  vpgl_perspective_camera<double>* cam = static_cast<vpgl_perspective_camera<double>*>(camera.ptr());
-  //  vgl_point_3d<double> const& cam_center = cam->camera_center();
+#if 0
+  if (camera->type_name().compare("vpgl_perspective_camera")==0) {
+    vpgl_perspective_camera<double>* cam = static_cast<vpgl_perspective_camera<double>*>(camera.ptr());
+    vgl_point_3d<double> const& cam_center = cam->camera_center();
 
-  //  if (cam_center.x() > bbox.max_x()) {
-  //    face_idx |= X_HIGH;
-  //  }
-  //  else if (cam_center.x() < bbox.min_x()) {
-  //    face_idx |= X_LOW;
-  //  }
-  //  if (cam_center.y() > bbox.max_y()) {
-  //    face_idx |= Y_HIGH;
-  //  }
-  //  else if (cam_center.y() < bbox.min_y()) {
-  //    face_idx |= Y_LOW;
-  //  }
-  //  if (cam_center.z() > bbox.max_x()) {
-  //    face_idx |= Z_HIGH;
-  //  }
-  //  else if (cam_center.z() < bbox.min_z()) {
-  //    face_idx |= Z_LOW;
-  //  }
-  //}
+    if (cam_center.x() > bbox.max_x()) {
+      face_idx |= X_HIGH;
+    }
+    else if (cam_center.x() < bbox.min_x()) {
+      face_idx |= X_LOW;
+    }
+    if (cam_center.y() > bbox.max_y()) {
+      face_idx |= Y_HIGH;
+    }
+    else if (cam_center.y() < bbox.min_y()) {
+      face_idx |= Y_LOW;
+    }
+    if (cam_center.z() > bbox.max_x()) {
+      face_idx |= Z_HIGH;
+    }
+    else if (cam_center.z() < bbox.min_z()) {
+      face_idx |= Z_LOW;
+    }
+  }
   // for other cameras, use projection and normals
-  //else 
+  else
+#endif // 0
   {
     // fix the face normals so that the vertices are the counter clockwise order
 #if 0
@@ -372,9 +350,10 @@ boxm_utils::visible_faces(vgl_box_3d<double> const& bbox, vpgl_camera_double_spt
 
   return face_idx;
 }
+
 boct_face_idx
 boxm_utils::visible_faces_cell(vgl_box_3d<double> const& bbox, vpgl_camera_double_sptr camera,
-                          double *xverts, double *yverts)
+                               double *xverts, double *yverts)
 {
   boct_face_idx face_idx = NONE;
   if (camera->type_name().compare("vpgl_perspective_camera")==0) {
@@ -401,7 +380,7 @@ boxm_utils::visible_faces_cell(vgl_box_3d<double> const& bbox, vpgl_camera_doubl
     }
   }
   // for other cameras, use projection and normals
-  else 
+  else
   {
     // fix the face normals so that the vertices are the counter clockwise order
 #if 0
@@ -456,6 +435,7 @@ boxm_utils::visible_faces_cell(vgl_box_3d<double> const& bbox, vpgl_camera_doubl
 
   return face_idx;
 }
+
 //: returns the faces of a box, the vertices are ordered in the normal direction
 void boxm_utils::faces_of_box_3d(vgl_box_3d<double> const& bbox,
                                  vcl_map<boct_face_idx, vcl_vector<vgl_point_3d<double> > >& faces)
@@ -948,7 +928,7 @@ bool boxm_utils::project_cube_xyz(vcl_vector< vgl_point_3d<double> > & corners,
 }
 
 
-bool boxm_utils::project_cube_xyz(vcl_vector< vgl_point_3d<double> > & corners,
+bool boxm_utils::project_cube_xyz(vcl_vector< vgl_point_3d<double> > & /*corners*/,
                                   boct_face_idx & vis_face_ids,
                                   vil_image_view<float> &front_xyz,
                                   vil_image_view<float> &back_xyz,
@@ -961,13 +941,8 @@ bool boxm_utils::project_cube_xyz(vcl_vector< vgl_point_3d<double> > & corners,
     double ds[]={vertdist[1],vertdist[0],vertdist[3],vertdist[2]};
     boxm_quad_scan_iterator poly_it(xs,ys);
     vgl_polygon<double> p(xs,ys,4);
-    if (vis_face_ids & Z_LOW){
-      quad_interpolate(poly_it,xs,ys,ds,front_xyz,0);
-    }
-    else
-    {
-      quad_interpolate(poly_it,xs,ys,ds,back_xyz,0);
-    }
+    if (vis_face_ids & Z_LOW){ quad_interpolate(poly_it,xs,ys,ds,front_xyz,0); }
+    else                     { quad_interpolate(poly_it,xs,ys,ds,back_xyz,0); }
   }
   {
     double xs[]={xverts[4],xverts[5],xverts[6],xverts[7]};
@@ -976,13 +951,8 @@ bool boxm_utils::project_cube_xyz(vcl_vector< vgl_point_3d<double> > & corners,
 
     boxm_quad_scan_iterator poly_it(xs,ys);
     vgl_polygon<double> p(xs,ys,4);
-    if (vis_face_ids & Z_HIGH){
-      quad_interpolate(poly_it,xs,ys,ds,front_xyz,0);
-    }
-    else
-    {
-      quad_interpolate(poly_it,xs,ys,ds,back_xyz,0);
-    }
+    if (vis_face_ids & Z_HIGH){ quad_interpolate(poly_it,xs,ys,ds,front_xyz,0); }
+    else                      { quad_interpolate(poly_it,xs,ys,ds,back_xyz,0); }
   }
   {
     double xs[]={xverts[7],xverts[3],xverts[0],xverts[4]};
@@ -990,13 +960,8 @@ bool boxm_utils::project_cube_xyz(vcl_vector< vgl_point_3d<double> > & corners,
     double ds[]={vertdist[7],vertdist[3],vertdist[0],vertdist[4]};
 
     boxm_quad_scan_iterator poly_it(xs,ys);
-    if (vis_face_ids & X_LOW){
-      quad_interpolate(poly_it,xs,ys,ds,front_xyz,0);
-    }
-    else
-    {
-      quad_interpolate(poly_it,xs,ys,ds,back_xyz,0);
-    }
+    if (vis_face_ids & X_LOW){ quad_interpolate(poly_it,xs,ys,ds,front_xyz,0); }
+    else                     { quad_interpolate(poly_it,xs,ys,ds,back_xyz,0); }
   }
   {
     double xs[]={xverts[1],xverts[2],xverts[6],xverts[5]};
@@ -1004,13 +969,8 @@ bool boxm_utils::project_cube_xyz(vcl_vector< vgl_point_3d<double> > & corners,
     double ds[]={vertdist[1],vertdist[2],vertdist[6],vertdist[5]};
 
     boxm_quad_scan_iterator poly_it(xs,ys);
-    if (vis_face_ids & X_HIGH){
-      quad_interpolate(poly_it,xs,ys,ds,front_xyz,0);
-    }
-    else
-    {
-      quad_interpolate(poly_it,xs,ys,ds,back_xyz,0);
-    }
+    if (vis_face_ids & X_HIGH){ quad_interpolate(poly_it,xs,ys,ds,front_xyz,0); }
+    else                      { quad_interpolate(poly_it,xs,ys,ds,back_xyz,0); }
   }
   {
     double xs[]={xverts[0],xverts[1],xverts[5],xverts[4]};
@@ -1019,14 +979,8 @@ bool boxm_utils::project_cube_xyz(vcl_vector< vgl_point_3d<double> > & corners,
 
     boxm_quad_scan_iterator poly_it(xs,ys);
     vgl_polygon<double> p(xs,ys,4);
-
-    if (vis_face_ids & Y_LOW){
-      quad_interpolate(poly_it,xs,ys,ds,front_xyz,0);
-    }
-    else
-    {
-      quad_interpolate(poly_it,xs,ys,ds,back_xyz,0);
-    }
+    if (vis_face_ids & Y_LOW){ quad_interpolate(poly_it,xs,ys,ds,front_xyz,0); }
+    else                     { quad_interpolate(poly_it,xs,ys,ds,back_xyz,0); }
   }
   {
     double xs[]={xverts[2],xverts[3],xverts[7],xverts[6]};
@@ -1035,14 +989,8 @@ bool boxm_utils::project_cube_xyz(vcl_vector< vgl_point_3d<double> > & corners,
 
     boxm_quad_scan_iterator poly_it(xs,ys);
     vgl_polygon<double> p(xs,ys,4);
-
-    if (vis_face_ids & Y_HIGH){
-      quad_interpolate(poly_it,xs,ys,ds,front_xyz,0);
-    }
-    else
-    {
-      quad_interpolate(poly_it,xs,ys,ds,back_xyz,0);
-    }
+    if (vis_face_ids & Y_HIGH){ quad_interpolate(poly_it,xs,ys,ds,front_xyz,0); }
+    else                      { quad_interpolate(poly_it,xs,ys,ds,back_xyz,0); }
   }
 
   return true;
@@ -1055,8 +1003,8 @@ bool boxm_utils::project_cube_fill_val( vcl_map<boct_face_idx,vcl_vector< vgl_po
                                         float val, vpgl_camera_double_sptr cam)
 {
 #if 0
-  vcl_map<boct_face_idx, vcl_vector<vgl_point_3d<double> > >::iterator face_it=faces.begin();
-  for (;face_it!=faces.end();++face_it)
+  for (vcl_map<boct_face_idx, vcl_vector<vgl_point_3d<double> > >::iterator face_it=faces.begin();
+       face_it!=faces.end(); ++face_it)
   {
     vcl_vector<vgl_point_3d<double> > face_corners=face_it->second;
     vcl_vector<vgl_point_2d<double> > face_projected=project_face(face_corners,cam);
@@ -1455,7 +1403,7 @@ bool boxm_utils::cube_exit_point(vgl_box_3d<double> cube,vgl_point_3d<double> pt
 }
 
 
-boxm_apm_traits<BOXM_APM_MOG_GREY>::apm_datatype 
+boxm_apm_traits<BOXM_APM_MOG_GREY>::apm_datatype
 boxm_utils::obtain_mog_grey_unit_mode()
 {
   bsta_gauss_f1 simple_gauss_f1(1.0f,0.1f);
@@ -1468,10 +1416,9 @@ boxm_utils::obtain_mog_grey_unit_mode()
   bsta_num_obs<simple_bsta_mixture_fixed_f1_3>  simple_obs_mix_gauss_val_f1(simple_mix_gauss_val_f1);
 
   return simple_obs_mix_gauss_val_f1;
-
 }
 
-boxm_apm_traits<BOXM_APM_MOG_GREY>::apm_datatype 
+boxm_apm_traits<BOXM_APM_MOG_GREY>::apm_datatype
 boxm_utils::obtain_mog_grey_zero_mode()
 {
   bsta_gauss_f1 simple_gauss_f1(0.0f,0.1f);
@@ -1486,7 +1433,7 @@ boxm_utils::obtain_mog_grey_zero_mode()
   return simple_obs_mix_gauss_val_f1;
 }
 
-boxm_apm_traits<BOXM_APM_MOG_GREY>::apm_datatype 
+boxm_apm_traits<BOXM_APM_MOG_GREY>::apm_datatype
 boxm_utils::obtain_mog_grey_single_mode(float  mean)
 {
   bsta_gauss_f1 simple_gauss_f1(mean,0.1f);
@@ -1499,19 +1446,17 @@ boxm_utils::obtain_mog_grey_single_mode(float  mean)
   bsta_num_obs<simple_bsta_mixture_fixed_f1_3>  simple_obs_mix_gauss_val_f1(simple_mix_gauss_val_f1);
 
   return simple_obs_mix_gauss_val_f1;
-
 }
 
 double boxm_utils::max_point_to_box_dist(vgl_box_3d<double> box,vgl_point_3d<double> pt)
 {
+  double dist_max=0;
 
-    double dist_max=0;
-
-    vcl_vector<vgl_point_3d<double> > corners=corners_of_box_3d(box);
-    for(unsigned i=0;i<corners.size();i++)
-    {
-        if(dist_max<(corners[i]-pt).length())
-            dist_max=(corners[i]-pt).length();
-    }
-    return dist_max;
+  vcl_vector<vgl_point_3d<double> > corners=corners_of_box_3d(box);
+  for (unsigned i=0;i<corners.size();i++)
+  {
+    if (dist_max<(corners[i]-pt).length())
+      dist_max=(corners[i]-pt).length();
+  }
+  return dist_max;
 }
