@@ -11,8 +11,6 @@
 //   <none yet>
 // \endverbatim
 
-#include <vgl/vgl_box_3d.h>
-
 #include <boct/boct_tree.h>
 #include <boct/boct_tree_cell_reader.h>
 #include <boxm/boxm_scene.h>
@@ -20,16 +18,19 @@
 #include <boxm/boxm_block.h>
 #include <boxm/opt/boxm_rt_sample.h>
 
+#include <vgl/vgl_point_3d.h>
+
 template <class T_loc, class T, class T_AUX>
 class boxm_aux_scene
 {
  public:
+   typedef enum {EMPTY=0, CLONE, LOAD, UNDEFINED } tree_creation_type ;
    typedef  boct_tree<T_loc, T> tree_type;
    typedef  boct_tree<T_loc, T_AUX> aux_tree_type;
-   boxm_aux_scene(){}
-   boxm_aux_scene(boxm_scene<tree_type>* scene, vcl_string suffix);
+   boxm_aux_scene() : aux_scene_(NULL), aux_storage_dir_("") {}
+   boxm_aux_scene(boxm_scene<tree_type>* scene, vcl_string suffix, tree_creation_type type);
 
-   ~boxm_aux_scene(){/*delete aux_scene_;*/}
+   ~boxm_aux_scene(){ /*delete aux_scene_;*/ }
 
    void init_scene(){}
 
