@@ -17,5 +17,7 @@ DECLARE_FUNC_CONS(boxm_proj_local_cam_process);
 DECLARE_FUNC_CONS(boxm_upload_mesh_process);
 DECLARE_FUNC_CONS(boxm_replace_const_app_process);
 DECLARE_FUNC_CONS(boxm_opt_bayesian_update_process);
+DECLARE_FUNC_CONS(boxm_init_scene_process);
+DECLARE_FUNC_CONS(boxm_clean_scene_process);
 
 #endif
