@@ -4,11 +4,10 @@
 #include <vpgl/vpgl_local_rational_camera.h>
 
 
-MAIN_ARGS( test_boxm_rational_camera_utils )
+static void test_boxm_rational_camera_utils()
 {
-  START ("BOXM RATIONAL CAMERA UTILS");
   vcl_string filename="camera0.txt";
-  
+
   vpgl_local_rational_camera<double>* rcam=read_local_rational_camera<double>( "./" + filename);
   vgl_plane_3d<double> top(0,0,1,-200);
   vgl_plane_3d<double> bottom(0,0,1,0);
@@ -19,5 +18,6 @@ MAIN_ARGS( test_boxm_rational_camera_utils )
 
   rcam->project(495,431,200,u,v);
   vgl_plane_3d<double>  plane_parallel=boxm_rational_camera_utils::boxm_find_parallel_image_plane(rcam,top,bottom,ni,nj);
-  SUMMARY();
 }
+
+TESTMAIN(test_boxm_rational_camera_utils);
