@@ -2,13 +2,21 @@
 #include <boxm/boxm_block.h>
 #include <boxm/boxm_block_vis_graph_iterator.h>
 #include <boxm/boxm_block_vis_graph_node.h>
+#include <boxm/boxm_cell_data_traits.h>
 #include <boxm/boxm_cell_vis_graph_iterator.h>
 #include <boxm/boxm_cell_vis_graph_node.h>
+#include <boxm/boxm_compute_scene_statistics.h>
 #include <boxm/boxm_compute_volume_visibility.h>
 #include <boxm/boxm_depth_image_triangle.h>
+#include <boxm/boxm_edge_sample.h>
+#include <boxm/boxm_edge_tangent_sample.h>
 #include <boxm/boxm_fill_in_mesh.h>
+#include <boxm/boxm_inf_line_sample.h>
+#include <boxm/boxm_init_scene.h>
+#include <boxm/boxm_mob_grey_processor.h>
 #include <boxm/boxm_mog_grey_processor.h>
 #include <boxm/boxm_neighb_graph_node.h>
+#include <boxm/boxm_plane_obs.h>
 #include <boxm/boxm_quad_scan_iterator.h>
 #include <boxm/boxm_rational_camera_utils.h>
 #include <boxm/boxm_raytrace_operations.h>
@@ -21,6 +29,8 @@
 #include <boxm/boxm_save_scene_raw.h>
 #include <boxm/boxm_scene.h>
 #include <boxm/boxm_scene_base.h>
+#include <boxm/boxm_scene_parser.h>
+#include <boxm/boxm_sigma_normalizer.h>
 #include <boxm/boxm_simple_grey_processor.h>
 #include <boxm/boxm_triangle_interpolation_iterator.h>
 #include <boxm/boxm_triangle_scan_iterator.h>
@@ -35,6 +45,5 @@
 #include <boxm/pro/boxm_register.h>
 
 #include <boxm/io/boxm_io_scene_base.h>
-#include <boxm/io/boxm_scene_parser.h>
 
 int main() { return 0; }
