@@ -1,11 +1,14 @@
+#include <bvpl/bvpl_combined_neighb_operator.h>
 #include <bvpl/bvpl_corner2d_kernel_factory.h>
 #include <bvpl/bvpl_create_directions.h>
 #include <bvpl/bvpl_direction_to_color_map.h>
+#include <bvpl/bvpl_discriminative_non_max_suppression.h>
 #include <bvpl/bvpl_edge_algebraic_mean_functor.h>
 #include <bvpl/bvpl_edge_geometric_mean_functor.h>
 #include <bvpl/bvpl_edge2d_functor.h>
 #include <bvpl/bvpl_edge2d_kernel_factory.h>
 #include <bvpl/bvpl_edge3d_kernel_factory.h>
+#include <bvpl/bvpl_find_surface_functor.h>
 #include <bvpl/bvpl_gauss_convolution_functor.h>
 #include <bvpl/bvpl_gauss3d_xx_kernel_factory.h>
 #include <bvpl/bvpl_kernel.h>
@@ -13,11 +16,15 @@
 #include <bvpl/bvpl_kernel_iterator.h>
 #include <bvpl/bvpl_local_max_functor.h>
 #include <bvpl/bvpl_neighb_operator.h>
+#include <bvpl/bvpl_neighborhood_kernel_factory.h>
+#include <bvpl/bvpl_negative_gauss_conv_functor.h>
 #include <bvpl/bvpl_opinion_functor.h>
+#include <bvpl/bvpl_positive_gauss_conv_functor.h>
 #include <bvpl/bvpl_subgrid_iterator.h>
 #include <bvpl/bvpl_susan_opinion_operator.h>
 #include <bvpl/bvpl_vector_operator.h>
 #include <bvpl/bvpl_voxel_subgrid.h>
+#include <bvpl/bvpl_weighted_cube_kernel_factory.h>
 
 #include <bvpl/pro/bvpl_processes.h>
 #include <bvpl/pro/bvpl_register.h>
