@@ -10,7 +10,7 @@
 template <class FUNC>
 bool test_directions(FUNC dir)
 {
-  bvpl_edge3d_kernel_factory kernels_3d(3,3,3);
+  bvpl_edge3d_kernel_factory kernels_3d(-1,1,-1,1,-1,1);
   bvpl_kernel_vector_sptr kernel_vec = kernels_3d.create_kernel_vector(dir);
 
   vcl_vector<vnl_float_3> axes1= dir.get_axes();
@@ -28,14 +28,15 @@ bool test_directions(FUNC dir)
   return result;
 }
 
-//: Test that directions created by functores are in fact stored in the kernels
-MAIN(test_vector_directions)
+//: Test that directions created by functors are in fact stored in the kernels
+static void test_vector_directions()
 {
   bvpl_create_directions_a dir1;
   TEST("Direction a", true, test_directions(dir1));
   bvpl_create_directions_b dir2;
   TEST("Direction b", true, test_directions(dir2));
-  bvpl_create_directions_c dir3;
+  bvpl_all_corner_dirs dir3;
   TEST("Direction c", true, test_directions(dir3));
-  SUMMARY();
 }
+
+TESTMAIN(test_vector_directions);
