@@ -8,37 +8,18 @@
 //
 // \verbatim
 //  Modifications
-//
 //   07 Mar.2008 - Ozge C. Ozcanli - Added support for VIL_PIXEL_FORMAT_RGB_FLOAT and VIL_PIXEL_FORMAT_FLOAT to the img_to_slab method
 //                                   Assumes the float image is already scaled to [0,1] range
-//
-//   08/20/2008 - Ibrahim Eden - Added the method
-//                               static vil_image_view<float> multiply_image_with_gaussian_kernel(vil_image_view<float> img, double gaussian_sigma);
-//
-//   09/03/2008 - Ibrahim Eden - Added the method
-//                               static vil_image_view<vxl_byte> detect_edges ...
-//
-//   09/11/2008 - Ibrahim Eden - Added the method
-//                               static void edge_distance_transform ...
-//
-//   09/12/2008 - Ibrahim Eden - Added the method
-//                               static int convert_uncertainty_from_meters_to_pixels ...
-//
-//   12/12/2008 - Ozge C. Ozcanli - Added the method
-//                                  static void warp_slab_nearest_neighbor ...
-//
-//   02/12/2009 - Ibrahim Eden - Added the method
-//                                  static void convert_edge_statistics_to_probability ...
-//
-//   07/14/2009 - Ibrahim Eden - Moved edge related functions to bvxm_edge_util
-//
+//   Aug. 20, 2008 - Ibrahim Eden - Added the method static vil_image_view<float> multiply_image_with_gaussian_kernel(vil_image_view<float> img, double gaussian_sigma);
+//   Sept 03, 2008 - Ibrahim Eden - Added the method static vil_image_view<vxl_byte> detect_edges ...
+//   Sept 11, 2008 - Ibrahim Eden - Added the method static void edge_distance_transform ...
+//   Dec. 12, 2008 - Ozge C. Ozcanli - Added the method static void warp_slab_nearest_neighbor ...
+//   Febr 12, 2009 - Ibrahim Eden - Added the method static void convert_edge_statistics_to_probability ...
+//   July 14, 2009 - Ibrahim Eden - Moved edge related functions to bvxm_edge_util
 // \endverbatim
 
-#include <vcl_string.h>
-#include <vcl_vector.h>
-#include <vcl_iostream.h>
-#include <vcl_cmath.h>
-#include <vcl_cassert.h>
+#include "grid/bvxm_voxel_slab.h"
+#include "bvxm_world_params.h"
 
 #include <vpgl/vpgl_camera.h>
 #include <vpgl/vpgl_rational_camera.h>
@@ -46,8 +27,6 @@
 #include <vgl/algo/vgl_h_matrix_2d.h>
 #include <vgl/vgl_point_3d.h>
 #include <vgl/vgl_box_3d.h>
-#include <vgl/vgl_plane_3d.h>
-#include <vgl/vgl_polygon.h>
 #include <vgl/vgl_intersection.h>
 
 #include <vnl/vnl_math.h>
@@ -65,8 +44,11 @@
 #include <vil/vil_pixel_format.h>
 #include <vil/vil_save.h> // for debug saving
 
-#include "grid/bvxm_voxel_slab.h"
-#include "bvxm_world_params.h"
+#include <vcl_string.h>
+#include <vcl_vector.h>
+#include <vcl_iostream.h>
+#include <vcl_cmath.h>
+#include <vcl_cassert.h>
 
 class bvxm_util
 {
@@ -158,6 +140,8 @@ class bvxm_util
 
   static vpgl_camera_double_sptr downsample_camera(vpgl_camera_double_sptr camera,unsigned int scale);
 
+  static int convert_uncertainty_from_meters_to_pixels(float uncertainty, bgeo_lvcs_sptr lvcs, vpgl_camera_double_sptr camera);
+
   static vpgl_camera_double_sptr downsample_persp_camera(vpgl_camera_double_sptr camera,unsigned int scale);
 
  protected:
@@ -270,6 +254,22 @@ void bvxm_util::warp_slab_nearest_neighbor(bvxm_voxel_slab<T> const& slab_in,
   vnl_matrix_fixed<double,3,3>::iterator Hdit = Hd.begin();
   for (; Hit != H.end(); ++Hit, ++Hdit)
     *Hit = (float)(*Hdit);
+  //JLM DEBUG
+#if 0
+  vnl_vector_fixed<float, 3> h00(0.0f,0.0f,1.0f), h01(0.0f,slab_out.ny(),1.0f);
+  vnl_vector_fixed<float, 3> h10(slab_out.nx(),0.0f, 1.0f),
+    h11(slab_out.nx(),slab_out.ny(), 1.0f);
+  vnl_vector_fixed<float, 3> th00=H*h00, th01=H*h01, th10=H*h10, th11=H*h11;
+  float x00 = th00[0]/th00[2], y00 = th00[1]/th00[2];
+  float x01 = th01[0]/th01[2], y01 = th01[1]/th01[2];
+  float x10 = th10[0]/th10[2], y10 = th10[1]/th10[2];
+  float x11 = th11[0]/th11[2], y11 = th11[1]/th11[2];
+  vcl_cout << "Warp slab\n";
+  vcl_cout << "(" << 0.0 << ' ' << 0.0 << ")->(" << x00 << ' ' << y00 << ")\n";
+  vcl_cout << "(" << 0.0 << ' ' << slab_out.ny() << ")->(" << x01 << ' ' << y01 << ")\n";
+  vcl_cout << "(" << slab_out.nx() << ' ' << 0.0 << ")->(" << x10 << ' ' << y10 << ")\n";
+  vcl_cout << "(" << slab_out.nx() << ' ' << slab_out.ny() << ")->(" << x11 << ' ' << y11 << ")\n";
+#endif
 
   //slab_out.fill(T(0.0)); // this should work whether T is a vector_fixed or a scalar
 
