@@ -6,6 +6,7 @@ DECLARE( test_voxel_storage_disk_cached );
 DECLARE( test_voxel_grid );
 DECLARE( test_basic_ops );
 DECLARE( test_grid_to_image_stack );
+DECLARE( test_bvxm_vrml );
 
 void register_tests()
 {
@@ -15,6 +16,7 @@ void register_tests()
   REGISTER( test_voxel_grid );
   REGISTER( test_basic_ops );
   REGISTER( test_grid_to_image_stack );
+  REGISTER( test_bvxm_vrml);
 }
 
 DEFINE_MAIN;
