@@ -1,14 +1,15 @@
 #include <bvxm/bvxm_voxel_world_sptr.h>
 
 #include <bvxm/bvxm_edge_ray_processor.h>
-#include <bvxm/bvxm_edge_util.h>
 #include <bvxm/bvxm_float_processor.h>
+#include <bvxm/bvxm_illum_util.h>
 #include <bvxm/bvxm_image_metadata.h>
 #include <bvxm/bvxm_lidar_processor.h>
 #include <bvxm/bvxm_mog_grey_processor.h>
 #include <bvxm/bvxm_mog_mc_processor.h>
 #include <bvxm/bvxm_mog_rgb_processor.h>
 #include <bvxm/bvxm_util.h>
+#include <bvxm/bvxm_von_mises_tangent_processor.h>
 #include <bvxm/bvxm_voxel_traits.h>
 #include <bvxm/bvxm_voxel_world.h>
 #include <bvxm/bvxm_world_params.h>
