@@ -44,8 +44,6 @@
 #include <sdet/sdet_fit_conics.h>
 #include <sdet/sdet_grid_finder_params.h>
 #include <sdet/sdet_grid_finder.h>
-//#include <sdet/sdet_read_mser_regions.h>
-//#include <sdet/sdet_vrml_display.h>
 #include <vgui/vgui.h>
 #include <vgui/vgui_find.h>
 #include <vgui/vgui_tableau.h>
@@ -78,8 +76,6 @@
 #include <brip/brip_max_scale_response.h>
 #include <sdet/sdet_watershed_region_proc_params.h>
 #include <sdet/sdet_watershed_region_proc.h>
-#include <sdet/sdet_vehicle_finder_params.h>
-#include <sdet/sdet_vehicle_finder.h>
 #include <sdet/sdet_region_proc_params.h>
 #include <sdet/sdet_region_proc.h>
 #include <strk/strk_region_info_params.h>
@@ -555,23 +551,24 @@ void segv_vil_segmentation_manager::load_image()
   // determine if the image can be made into a J2K-nitf pyramid
   char const* fmtp = image->file_format();
   vcl_string file_fmt = "";
-  if(fmtp) file_fmt = fmtp;//fmtp can be 0 for undefined formats
-  if(file_fmt == "nitf21")
+  if (fmtp) file_fmt = fmtp;//fmtp can be 0 for undefined formats
+  if (file_fmt == "nitf21")
+  {
+    vil_nitf2_image* nitf_resc = static_cast<vil_nitf2_image*>(image.ptr());
+    if (nitf_resc->is_jpeg_2000_compressed())
     {
-      vil_nitf2_image* nitf_resc = static_cast<vil_nitf2_image*>(image.ptr());
-      if(nitf_resc->is_jpeg_2000_compressed())
-        {
-          vil_j2k_nitf2_pyramid_image_resource* j2k_nitf = 
-            new vil_j2k_nitf2_pyramid_image_resource(image);
-          image = j2k_nitf;
-          pyrm = true;
-        }
-    }else if(file_fmt == "j2k"){
-      vil_j2k_pyramid_image_resource* j2k_pyr = 
-        new vil_j2k_pyramid_image_resource(image);     
-      image = j2k_pyr;
+      vil_j2k_nitf2_pyramid_image_resource* j2k_nitf =
+        new vil_j2k_nitf2_pyramid_image_resource(image);
+      image = j2k_nitf;
       pyrm = true;
     }
+  }
+  else if (file_fmt == "j2k") {
+    vil_j2k_pyramid_image_resource* j2k_pyr =
+      new vil_j2k_pyramid_image_resource(image);
+    image = j2k_pyr;
+    pyrm = true;
+  }
 #endif //HAS_J2K
   if (greyscale&&!pyrm)
   {
@@ -620,23 +617,24 @@ void segv_vil_segmentation_manager::load_image_nomenu(vcl_string const& path)
 // determine if the image can be made into a J2K-nitf pyramid
   char const* fmtp = image->file_format();
   vcl_string file_fmt = "";
-  if(fmtp) file_fmt = fmtp;//fmtp can be 0 for undefined formats
-  if(file_fmt == "nitf21")
+  if (fmtp) file_fmt = fmtp;//fmtp can be 0 for undefined formats
+  if (file_fmt == "nitf21")
+  {
+    vil_nitf2_image* nitf_resc = static_cast<vil_nitf2_image*>(image.ptr());
+    if (nitf_resc->is_jpeg_2000_compressed())
     {
-      vil_nitf2_image* nitf_resc = static_cast<vil_nitf2_image*>(image.ptr());
-      if(nitf_resc->is_jpeg_2000_compressed())
-        {
-          vil_j2k_nitf2_pyramid_image_resource* j2k_nitf = 
-            new vil_j2k_nitf2_pyramid_image_resource(image);
-          image = j2k_nitf;
-          pyrm = true;
-        }
-    }else if(file_fmt == "j2k"){
-      vil_j2k_pyramid_image_resource* j2k_pyr = 
-        new vil_j2k_pyramid_image_resource(image);
-      image = j2k_pyr;
+      vil_j2k_nitf2_pyramid_image_resource* j2k_nitf =
+        new vil_j2k_nitf2_pyramid_image_resource(image);
+      image = j2k_nitf;
       pyrm = true;
     }
+  }
+  else if (file_fmt == "j2k") {
+    vil_j2k_pyramid_image_resource* j2k_pyr =
+      new vil_j2k_pyramid_image_resource(image);
+    image = j2k_pyr;
+    pyrm = true;
+  }
 #endif //HAS_J2K
   vgui_range_map_params_sptr rmps = range_params(image);
 
@@ -1863,3 +1861,132 @@ void segv_vil_segmentation_manager::extrema()
     }
   }
 }
+
+void segv_vil_segmentation_manager::rot_extrema()
+{
+  vil_image_resource_sptr img = selected_image();
+  if (!img)
+  {
+    vcl_cout<< "In segv_vil_segmentation_manager::extrema - no image\n";
+    return;
+  }
+  static float lambda0 = 1.0f;
+  static float lambda1 = 1.0f;
+  static float theta_inc = 0.0f;
+  static bool bright = true;
+  vgui_dialog extrema_dialog("Detect Extrema");
+  extrema_dialog.field("lambda0",lambda0);
+  extrema_dialog.field("lambda1",lambda1);
+  extrema_dialog.field("theta increment",theta_inc);
+  extrema_dialog.checkbox("Bright Extrema?(check)",bright);
+  if (!extrema_dialog.ask())
+    return;
+  vul_timer t;
+  vil_image_view<float> fimg = brip_vil_float_ops::convert_to_float(img);
+  vil_image_view<float> output = brip_vil_float_ops::extrema_rotational(fimg, lambda0, lambda1, theta_inc, bright);
+  unsigned ni = output.ni(), nj = output.nj();
+  vil_image_view<float> res(ni, nj), mask(ni, nj);
+  for (unsigned j = 0; j<nj; ++j)
+    for (unsigned i = 0; i<ni; ++i)
+    {
+      res(i,j) = output(i,j,0);
+      mask(i,j) = output(i,j,2);
+    }
+
+  vil_image_resource_sptr res_resc = vil_new_image_resource_of_view(res);
+  vil_image_resource_sptr msk_resc = vil_new_image_resource_of_view(mask);
+  vil_image_view<vil_rgb<vxl_byte> > rgb = brip_vil_float_ops::combine_color_planes(img, res_resc, msk_resc);
+  this->add_image(vil_new_image_resource_of_view(rgb));
+}
+
+void segv_vil_segmentation_manager::beaudet()
+{
+  vil_image_resource_sptr img = selected_image();
+  if (!img)
+  {
+    vcl_cout<< "In segv_vil_segmentation_manager::beaudet - no image\n";
+    return;
+  }
+  static float sigma = 1.0f;
+  static bool determinant = true;
+  vgui_dialog beaudet_dialog("beaudet");
+  beaudet_dialog.field("sigma", sigma);
+  beaudet_dialog.checkbox("Determinant(or Trace)", determinant);
+  if (!beaudet_dialog.ask())
+    return;
+  int ni = img->ni(), nj = img->nj();
+  vil_image_view<float> fimg = brip_vil_float_ops::convert_to_float(img);
+  vil_image_view<float> smooth = brip_vil_float_ops::gaussian(fimg, sigma);
+  vil_image_view<float> Ixx(ni,nj), Ixy(ni, nj), Iyy(ni, nj);
+  brip_vil_float_ops::hessian_3x3(smooth, Ixx, Ixy, Iyy);
+  vil_image_view<float> beau =
+    brip_vil_float_ops::beaudet(Ixx, Ixy, Iyy, determinant);
+  this->add_image(vil_new_image_resource_of_view(beau));
+}
+
+void segv_vil_segmentation_manager::parallel_coverage()
+{
+  static brip_para_cvrg_params pcp;
+  static bool combined=true;
+  vgui_dialog para_dialog("Parallel Coverage");
+  para_dialog.field("Sigma", pcp.sigma_);
+  para_dialog.field("Projection Width", pcp.proj_width_);
+  para_dialog.field("Projection Height", pcp.proj_height_);
+  para_dialog.checkbox("Display Coverage and Direction Combined", combined);
+  para_dialog.checkbox("Verbose", pcp.verbose_);
+  if (!para_dialog.ask())
+    return;
+  vil_image_resource_sptr img = selected_image();
+  brip_para_cvrg pc(pcp);
+  pc.do_coverage(img);
+  vil_image_resource_sptr cov_res;
+  if (combined)
+    cov_res = vil_new_image_resource_of_view(pc.get_combined_image());
+  else
+    cov_res = vil_new_image_resource_of_view(pc.get_detection_image());
+  this->add_image(cov_res);
+}
+
+//: it recives and image of line definitions and draws the lines on the tableau.
+// The image is expected having three planes to save (x,y,theta) of each line. 
+// (x,y) is the position of the edge and theta is the direction angle in radians
+void segv_vil_segmentation_manager::draw_line_image()
+{
+  vgui_dialog file_dlg("Edge File");
+  static vcl_string filename = "";
+  static vcl_string ext = "*.*";
+  file_dlg.file("Edge filename:", ext, filename);
+  if (!file_dlg.ask())
+    return;
+  vil_image_view_base_sptr img_sptr = vil_load(filename.c_str());
+  if (img_sptr->pixel_format() == VIL_PIXEL_FORMAT_FLOAT) {
+    vil_image_view<float> edge_image(img_sptr);
+    if (edge_image.nplanes() < 3) {
+      vcl_cout << "The image should have at least 3 planes" << vcl_endl;
+      return;
+    }
+    bgui_vtol2D_tableau_sptr t2D = this->selected_vtol2D_tab();
+    if (!t2D)
+      return;
+
+    for (unsigned i=0; i<edge_image.ni(); i++) {
+      for (unsigned j=0; j<edge_image.nj(); j++) {
+        double x = edge_image(i,j,0);
+        double y = edge_image(i,j,1);
+        double theta = edge_image(i,j,2);
+        double a,b;
+        a = x-0.5*vcl_cos(theta);
+        b = y-0.5*vcl_sin(theta);
+        vgl_point_2d<double> p0(a,b);
+        a = x+0.5*vcl_cos(theta); 
+        b = y+0.5*vcl_sin(theta);
+        vgl_point_2d<double> p1(a,b);
+        // define a line
+        vsol_line_2d_sptr line = new vsol_line_2d(p0,p1);
+        t2D->add_vsol_line_2d(line);
+      }
+    }
+  } else 
+    vcl_cout << "Pixel format: " << img_sptr->pixel_format() << " is not implemented yet" << vcl_endl;
+  
+}
\ No newline at end of file
