@@ -24,18 +24,21 @@ class vpro_roi_process : public vpro_vil_video_process
                    const unsigned x0,
                    const unsigned y0,
                    const unsigned xsize,
-                   const unsigned ysize);
-  ~vpro_roi_process();
+                   const unsigned ysize,
+                   vcl_string const& type = "ImageList")
+  : x0_(x0), y0_(y0), xsize_(xsize), ysize_(ysize), type_(type), video_file_(video_file) {}
+  ~vpro_roi_process() {}
   virtual process_data_type get_output_type() const { return IMAGE; }
   virtual bool execute();
   virtual bool finish();
  private:
-  vpro_roi_process();
+  vpro_roi_process() {}
   //members
   unsigned x0_;
   unsigned y0_;
   unsigned xsize_;
   unsigned ysize_;
+  vcl_string type_;
   vcl_string video_file_;//output file name
   vcl_list<vil_image_resource_sptr> out_frames_;
 };
