@@ -38,7 +38,8 @@
 #include <vimt3d/vimt3d_transform_3d.h>
 #include <vimt3d/vimt3d_add_all_loaders.h>
 #include <vimt3d/vimt3d_resample_trilinear.h>
-
+#include <vgl/vgl_vector_3d.h>
+#include <vgl/vgl_point_3d.h>
 
 //=========================================================================
 // Static function to create a static logger when first required
@@ -208,31 +209,31 @@ class operand
     return vimt3d_image_3d_of<int>();
   }
 
-
-  void print_summary(vcl_ostream &ss) const
+  void print_summary(vcl_ostream &os) const
   {
     // Forward declaration.
-    vcl_ostream& operator <<( vcl_ostream&ss, const operand::operand_type_t& t);
+    vcl_ostream& operator <<( vcl_ostream&os, const operand::operand_type_t& t);
 
-    ss << operand_type_ << ": ";
+    os << operand_type_ << ": ";
     switch (operand_type_)
     {
      case e_string:
-      ss << string_;
+      os << string_;
       break;
      case e_image_3d_of_double:
-      ss << vsl_stream_summary(image_3d_of_double_);
+      os << vsl_stream_summary(image_3d_of_double_);
       break;
      case e_image_3d_of_float:
-      ss << vsl_stream_summary(image_3d_of_float_);
+      os << vsl_stream_summary(image_3d_of_float_);
       break;
      case e_image_3d_of_int:
-      ss << vsl_stream_summary(image_3d_of_int_);
+      os << vsl_stream_summary(image_3d_of_int_);
       break;
      case e_double:
-      ss << double_;
+      os << double_;
       break;
      default: {
+      os << "Unknown operand_type: " << operand_type_;
       vcl_ostringstream ss;
       ss << "Unknown operand_type: " << operand_type_;
       throw mbl_exception_abort(ss.str()); }
@@ -261,7 +262,6 @@ class operand
     return false;
   }
 
-
   operand deep_copy() const
   {
     switch (operand_type_)
@@ -298,8 +298,8 @@ class operand
   }
 };
 
-void vsl_print_summary( vcl_ostream&ss, const operand& p) { p.print_summary(ss); }
-vcl_ostream& operator <<( vcl_ostream&ss, const operand& p) { p.print_summary(ss); return ss; }
+void vsl_print_summary( vcl_ostream&os, const operand& p) { p.print_summary(os); }
+vcl_ostream& operator <<( vcl_ostream&os, const operand& p) { p.print_summary(os); return os; }
 
 void vsl_print_summary(vcl_ostream& os, const vcl_deque<operand> &v)
 {
@@ -314,26 +314,27 @@ void vsl_print_summary(vcl_ostream& os, const vcl_deque<operand> &v)
     os << " ...\n";
 }
 
-vcl_ostream& operator <<( vcl_ostream&ss, const operand::operand_type_t& t)
+vcl_ostream& operator <<( vcl_ostream&os, const operand::operand_type_t& t)
 {
   switch (t)
   {
     case operand::e_string:
-      ss << "string"; break;
+      os << "string"; break;
     case operand::e_image_3d_of_double:
-      ss << "image_3d_of_double"; break;
+      os << "image_3d_of_double"; break;
     case operand::e_image_3d_of_float:
-      ss << "image_3d_of_float"; break;
+      os << "image_3d_of_float"; break;
     case operand::e_image_3d_of_int:
-      ss << "image_3d_of_int"; break;
+      os << "image_3d_of_int"; break;
     case operand::e_double:
-      ss << "double"; break;
+      os << "double"; break;
     default: {
+      os << "Unknown operand_type: " << static_cast<int>(t);
       vcl_ostringstream ss;
       ss << "Unknown operand_type: " << static_cast<int>(t);
       throw mbl_exception_abort(ss.str()); }
   }
-  return ss;
+  return os;
 }
 
 typedef vcl_deque<operand> opstack_t;
@@ -345,7 +346,7 @@ static named_store_t named_store;
 void print_operations(vcl_ostream&);
 
 //: Operation implementation
-void help(opstack_t& s)
+void help(opstack_t& )
 {
   vcl_cerr <<
     "usage: image3d_math [--operand | operation] [--operand | operation] ... --operand\n"
@@ -708,15 +709,24 @@ void save_to_mat__image_3d_of_int__string(opstack_t& s)
   vimt3d_image_3d_of<int> o2(s[1].as_image_3d_of_int());
   const vil3d_image_view<int>& o2_image = o2.image();;
 
-  vcl_ofstream output(o1.c_str());
+  vcl_ofstream output_file;
+  vcl_ostream *output;
 
-  if (!output)
+  if (o1 == "-")
+    output = &vcl_cout;
+  else
+  {
+    output_file.open(o1.c_str());
+    output = &output_file;
+  }
+
+  if (!*output)
     mbl_exception_throw_os_error(o1);
 
-  //copy precision length from console to output file
-  output.precision(vcl_cout.precision());
+  // copy precision length from console to output file
+  output->precision(vcl_cout.precision());
 
-  output <<
+  (*output) <<
     "# Created by vxl/image3d_math\n"
     "# name: image3d\n"
     "# type: matrix\n"
@@ -726,7 +736,7 @@ void save_to_mat__image_3d_of_int__string(opstack_t& s)
   for (unsigned k=0;k<o2_image.nk();++k)
     for (unsigned j=0;j<o2_image.nj();++j)
       for (unsigned i=0;i<o2_image.ni();++i)
-        output <<  o2_image(i,j,k) << '\n';
+        (*output) <<  o2_image(i,j,k) << '\n';
 
   s.pop_front();
   s.pop_front();
@@ -741,15 +751,25 @@ void save_to_mat__image_3d_of_float__string(opstack_t& s)
   vimt3d_image_3d_of<float> o2(s[1].as_image_3d_of_float());
   const vil3d_image_view<float>& o2_image = o2.image();;
 
-  vcl_ofstream output(o1.c_str());
 
-  if (!output)
+  vcl_ofstream output_file;
+  vcl_ostream *output;
+
+  if (o1 == "-")
+    output = &vcl_cout;
+  else
+  {
+    output_file.open(o1.c_str());
+    output = &output_file;
+  }
+
+  if (!*output)
     mbl_exception_throw_os_error(o1);
 
-  //copy precision length from console to output file
-  output.precision(vcl_cout.precision());
+  // copy precision length from console to output file
+  output->precision(vcl_cout.precision());
 
-  output <<
+  (*output) <<
     "# Created by vxl/image3d_math\n"
     "# name: image3d\n"
     "# type: matrix\n"
@@ -759,7 +779,7 @@ void save_to_mat__image_3d_of_float__string(opstack_t& s)
   for (unsigned k=0;k<o2_image.nk();++k)
     for (unsigned j=0;j<o2_image.nj();++j)
       for (unsigned i=0;i<o2_image.ni();++i)
-        output <<  o2_image(i,j,k) << '\n';
+        (*output) <<  o2_image(i,j,k) << '\n';
 
   s.pop_front();
   s.pop_front();
@@ -775,15 +795,25 @@ void save_to_mat__image_3d_of_double__string(opstack_t& s)
   vimt3d_image_3d_of<double> o2(s[1].as_image_3d_of_double());
   const vil3d_image_view<double>& o2_image = o2.image();;
 
-  vcl_ofstream output(o1.c_str());
 
-  if (!output)
+  vcl_ofstream output_file;
+  vcl_ostream *output;
+
+  if (o1 == "-")
+    output = &vcl_cout;
+  else
+  {
+    output_file.open(o1.c_str());
+    output = &output_file;
+  }
+
+  if (!*output)
     mbl_exception_throw_os_error(o1);
 
-  //copy precision length from console to output file
-  output.precision(vcl_cout.precision());
+  // copy precision length from console to output file
+  output->precision(vcl_cout.precision());
 
-  output <<
+  (*output) <<
     "# Created by vxl/image3d_math\n"
     "# name: image3d\n"
     "# type: matrix\n"
@@ -793,7 +823,7 @@ void save_to_mat__image_3d_of_double__string(opstack_t& s)
   for (unsigned k=0;k<o2_image.nk();++k)
     for (unsigned j=0;j<o2_image.nj();++j)
       for (unsigned i=0;i<o2_image.ni();++i)
-        output <<  o2_image(i,j,k) << '\n';
+        (*output) <<  o2_image(i,j,k) << '\n';
 
   s.pop_front();
   s.pop_front();
@@ -910,17 +940,17 @@ void convert_to_int__image_3d_of_double(opstack_t& s)
   s.push_front(operand(result));
 }
 
-void option_load_as_image_int(opstack_t& s)
+void option_load_as_image_int(opstack_t& )
 {
   global_option_load_as_image = image3d_int_t;
 }
 
-void option_load_as_image_double(opstack_t& s)
+void option_load_as_image_double(opstack_t& )
 {
   global_option_load_as_image = image3d_double_t;
 }
 
-void option_load_as_image_float(opstack_t& s)
+void option_load_as_image_float(opstack_t& )
 {
   global_option_load_as_image = image3d_float_t;
 }
@@ -1001,6 +1031,41 @@ void copy__image_3d_of_int(opstack_t& s)
   s.push_front(operand(result));
 }
 
+void copy_coordinate_frame__image_3d_of_float__image_3d_of_float(opstack_t& s)
+{
+  assert(s.size() >= 2);
+  vimt3d_image_3d_of<float> o1(s[1].as_image_3d_of_float());
+  vimt3d_image_3d_of<float> o2(s[0].as_image_3d_of_float());
+  const vil3d_image_view<float>& i_vox = o1.image();
+  const vimt3d_transform_3d& i_w2i = o2.world2im();
+
+  vimt3d_image_3d_of<float> result;
+  result.image().deep_copy(i_vox);
+  result.world2im() = i_w2i;
+ 
+  s.pop_front();
+  s.pop_front();
+
+  s.push_front(operand(result));
+}
+
+void copy_coordinate_frame__image_3d_of_int__image_3d_of_int(opstack_t& s)
+{
+  assert(s.size() >= 2);
+  vimt3d_image_3d_of<int> o1(s[1].as_image_3d_of_int());
+  vimt3d_image_3d_of<int> o2(s[0].as_image_3d_of_int());
+  const vil3d_image_view<int>& i_vox = o1.image();
+  const vimt3d_transform_3d& i_w2i = o2.world2im();
+
+  vimt3d_image_3d_of<int> result;
+  result.image().deep_copy(i_vox);
+  result.world2im() = i_w2i;
+
+  s.pop_front();
+  s.pop_front();
+
+  s.push_front(operand(result));
+}
 
 void copy__double(opstack_t& s)
 {
@@ -1039,7 +1104,6 @@ void print_overlap__image_3d_of_float__image_3d_of_float(opstack_t& s)
         sum2 += p2;
       }
 
-
   vcl_cout << "Tanamoto: " << gTanamoto_num/gTanamoto_den <<
     " Volume Change: " << (sum2-sum1)/sum1 << vcl_endl;
 
@@ -1077,9 +1141,8 @@ void print_overlap__image_3d_of_int__image_3d_of_int(opstack_t& s)
         sum2 += p2;
       }
 
-  vcl_cout << "Tanamoto: " << static_cast<double>(Tanamoto_num)/Tanamoto_den <<
-    " Volume Change: " << (static_cast<double>(sum2)-sum1)/sum1 << vcl_endl;
-
+  vcl_cout << "Tanamoto: " << static_cast<double>(Tanamoto_num)/Tanamoto_den
+           << " Volume Change: " << (static_cast<double>(sum2)-sum1)/sum1 << vcl_endl;
 
   s.pop_front();
   s.pop_front();
@@ -1300,7 +1363,6 @@ void local_z_normalise__image_3d_of_float__double(opstack_t& s)
   double o1(s[0].as_double());
   vimt3d_image_3d_of<float> o2(s[1].as_image_3d_of_float());
 
-
   vgl_vector_3d<double> voxel_size=o2.world2im().inverse().delta(
     vgl_point_3d<double>(0,0,0), vgl_vector_3d<double>(1.0,1.0,1.0) );
 
@@ -1446,6 +1508,12 @@ class operations
     add_operation("--copy", &copy__image_3d_of_float,
                   function_type_t() << operand::e_image_3d_of_float,
                   "image", "image image", "Duplicate image onto stack");
+    add_operation("--copy_coordinate_frame", &copy_coordinate_frame__image_3d_of_int__image_3d_of_int,
+                  function_type_t() << operand::e_image_3d_of_int << operand::e_image_3d_of_int,
+                  "image_v image_c", "image", "create image that is voxels of image_v and the world to image transform of image_c");
+    add_operation("--copy_coordinate_frame", &copy_coordinate_frame__image_3d_of_float__image_3d_of_float,
+                  function_type_t() << operand::e_image_3d_of_float << operand::e_image_3d_of_float,
+                  "image_v image_c", "image", "create image that is voxels of image_v and the world to image transform of image_c");
     add_operation("--diff", &diff__double__double,
                   function_type_t() << operand::e_double << operand::e_double,
                   "A B", "A-B", "Subtract values A minus B");
@@ -1571,22 +1639,22 @@ class operations
                   "im_A im_B", "im_A+B", "Add corresponding voxels of im_A and im_B");
     add_operation("--voxel_product", &voxel_product__image_3d_of_float,
                   function_type_t() << operand::e_image_3d_of_float,
-                  "image", "value", "Product of all the voxel values.");
+                  "image", "value", "Product over all the voxel values.");
     add_operation("--voxel_product", &voxel_product__image_3d_of_int,
                   function_type_t() << operand::e_image_3d_of_int,
-                  "image", "value", "Product of all the voxel values.");
+                  "image", "value", "Product over all the voxel values.");
     add_operation("--voxel_size", &voxel_size__image_3d_of_int,
                   function_type_t() << operand::e_image_3d_of_int,
-                  "image", "value", "Sum of all the voxel values.");
+                  "image", "x_length y_length z_length", "Length of each side of a voxel.");
     add_operation("--voxel_size", &voxel_size__image_3d_of_float,
                   function_type_t() << operand::e_image_3d_of_float,
-                  "image", "value", "Sum of all the voxel values.");
+                  "image", "x_length y_length z_length", "Length of each side of a voxel.");
     add_operation("--voxel_sum", &voxel_sum__image_3d_of_float,
                   function_type_t() << operand::e_image_3d_of_float,
-                  "image", "value", "Sum of all the voxel values.");
+                  "image", "value", "Sum over all the voxel values.");
     add_operation("--voxel_sum", &voxel_sum__image_3d_of_int,
                   function_type_t() << operand::e_image_3d_of_int,
-                  "image", "value", "Sum of all the voxel values.");
+                  "image", "value", "Sum over all the voxel values.");
 
     // Check they are correctly sorted.
     vcl_vector<vcl_string>::iterator it=names_.begin(), end=names_.end();
@@ -1614,8 +1682,8 @@ class operations
     typedef vcl_pair<vcl_vector<vcl_string>::iterator, vcl_vector<vcl_string>::iterator> range_t;
     range_t range =
       vcl_equal_range(singleton_.names_.begin(), singleton_.names_.end(), name);
-    for (unsigned i = distance(singleton_.names_.begin(), range.first),
-      end = distance(singleton_.names_.begin(), range.second); i!=end; ++i)
+    for (vcl_ptrdiff_t i = distance(singleton_.names_.begin(), range.first),
+         end = distance(singleton_.names_.begin(), range.second); i!=end; ++i)
     {
       if (operation_type_matches(singleton_.function_types_[i], stack))
       {
@@ -1628,30 +1696,30 @@ class operations
        << "\nStack is :\n" << vsl_stream_summary(stack);
     throw vcl_runtime_error(ss.str());
   }
-  static void print(vcl_ostream& ss)
+  static void print(vcl_ostream& os)
   {
     unsigned n = singleton_.names_.size();
 
     for (unsigned i=0; i<n; ++i)
     {
       vcl_string name = singleton_.names_[i].substr(2);
-      ss << vul_string_upcase(name) << ":  " <<
-        singleton_.help_desc_[i] << "\n    usage: " <<
-        singleton_.help_input_[i] << ' ' << singleton_.names_[i];
+      os << vul_string_upcase(name) << ":  "
+         << singleton_.help_desc_[i] << "\n    usage: "
+         << singleton_.help_input_[i] << ' ' << singleton_.names_[i];
       if (!singleton_.help_output_[i].empty())
-        ss << " => " << singleton_.help_output_[i];
-      ss << "\n    types: " ;
+        os << " => " << singleton_.help_output_[i];
+      os << "\n    types: " ;
       if (singleton_.function_types_[i].empty())
-        ss << "null";
+        os << "null";
       else for (unsigned j=0, nj=singleton_.function_types_[i].size(); j<nj; ++j)
-        ss << singleton_.function_types_[i][j] << ' ';
-      ss << "\n\n";
+        os << singleton_.function_types_[i][j] << ' ';
+      os << "\n\n";
     }
   }
 };
 
 operations operations::singleton_ = operations();
-void print_operations(vcl_ostream&ss) { operations::print(ss); }
+void print_operations(vcl_ostream&os) { operations::print(os); }
 
 //========================================================================
 // Actual main function
@@ -1718,4 +1786,4 @@ int main(int argc, char*argv[])
 {
   vcl_cerr << "ERROR: image3d_math needs exception support to compile properly.\n";
 }
-#endif
+#endif // VCL_HAS_EXCEPTIONS
