@@ -18,10 +18,12 @@
 #include <vimt/vimt_image_pyramid_builder.h>
 #include <vimt/vimt_image_pyramid.h>
 #include <vimt/vimt_load.h>
+#include <vimt/vimt_reflect.h>
 #include <vimt/vimt_resample_bilin.h>
 #include <vimt/vimt_sample_grid_bilin.h>
 #include <vimt/vimt_sample_grid_bicub.h>
 #include <vimt/vimt_sample_profile_bilin.h>
+#include <vimt/vimt_save.h>
 #include <vimt/vimt_scale_pyramid_builder_2d.h>
 #include <vimt/vimt_transform_2d.h>
 #include <vimt/vimt_transform_util_2d.h>
