@@ -6,10 +6,12 @@
 #include <vimt3d/vimt3d_image_3d.h>
 #include <vimt3d/vimt3d_image_3d_of.h>
 #include <vimt3d/vimt3d_load.h>
+#include <vimt3d/vimt3d_reflect.h>
 #include <vimt3d/vimt3d_resample_tricubic.h>
 #include <vimt3d/vimt3d_resample_trilinear.h>
 #include <vimt3d/vimt3d_sample_grid_trilin.h>
 #include <vimt3d/vimt3d_sample_profile_trilin.h>
+#include <vimt3d/vimt3d_sample_transformed_blob.h>
 #include <vimt3d/vimt3d_save.h>
 #include <vimt3d/vimt3d_slice.h>
 #include <vimt3d/vimt3d_transform_3d.h>
