@@ -23,7 +23,8 @@
 #include <vcl_cstdlib.h> // for atoi()
 
 int
-main(int argc, char** argv) {
+main(int argc, char** argv)
+{
   if (argc < 3)
   {
     vcl_cerr << "Syntax: example2_threshold file_in file_out [threshold]\n";
@@ -39,7 +40,7 @@ main(int argc, char** argv) {
   }
 
   // The threshold value:
-  vxl_byte threshold = (argc < 4) ? 128 : vcl_atoi(argv[3]);
+  vxl_byte threshold = (argc < 4) ? 128 : vxl_byte(vcl_atoi(argv[3]));
 
   // perform thresholding:
   vil1_image out = vepl_threshold(in,threshold,0,255);
