@@ -27,8 +27,6 @@
 #include <vgl/vgl_clip.h>
 #include <vgl/vgl_distance.h>
 #include <vgl/vgl_lineseg_test.h>
-//#include <vgl/vgl_polygon_test.h>
-//#include <vgl/vgl_triangle_test.h>
 #include <vgl/vgl_1d_basis.h>
 #include <vgl/vgl_intersection.h>
 
@@ -159,22 +157,12 @@ static void test_vector_3d()
   TEST("!orthogonal", orthogonal(v,v1,0.1), false); // even not with tolorance
   TEST("orthogonal", orthogonal(v,cross_product(v1,v)), true);
   TEST("orthogonal", orthogonal(v1,cross_product(v1,v)), true);
-  vgl_vector_3d<double> n0(0.0, 0.0, 1.0), n1(0.0, 0.707107, 0.707107);
-  vgl_vector_3d<double> n2(0.707107, 0.707107, 0.0);
+
   vgl_vector_3d<double> tr[4];
-  tr[0] = n0.orthogonal_vectors(0.0);
-  tr[1] = n0.orthogonal_vectors(0.25);
-  tr[2] = n0.orthogonal_vectors(0.5);
-  tr[3] = n0.orthogonal_vectors(0.75);
   double check = 0.0;
-  for (unsigned i = 0; i<4; ++i)
-  {
-    double d = dot_product<double>(n0, tr[i]);
-    check += d*d;
-    d = dot_product<double>(tr[i], tr[i])-1.0;
-    check += d*d;
-  }
-  TEST_NEAR("orthogonal vectors case I", check, 0.0, 1e-8);
+
+  // Orthogonal vectors test case 1
+  vgl_vector_3d<double> n1(1.0, 0.0, 0.0);
   check = 0.0;
   tr[0] = n1.orthogonal_vectors(0.0);
   tr[1] = n1.orthogonal_vectors(0.25);
@@ -187,7 +175,10 @@ static void test_vector_3d()
     d = dot_product<double>(tr[i], tr[i])-1.0;
     check += d*d;
   }
-  TEST_NEAR("orthogonal vectors case II", check, 0.0, 1e-8);
+  TEST_NEAR("orthogonal vectors case 1", check, 0.0, 1e-8);
+
+  // Orthogonal vectors test case 2
+  vgl_vector_3d<double> n2(0.0, 1.0, 0.0);
   check = 0.0;
   tr[0] = n2.orthogonal_vectors(0.0);
   tr[1] = n2.orthogonal_vectors(0.25);
@@ -200,7 +191,55 @@ static void test_vector_3d()
     d = dot_product<double>(tr[i], tr[i])-1.0;
     check += d*d;
   }
-  TEST_NEAR("orthogonal vectors case III", check, 0.0, 1e-8);
+  TEST_NEAR("orthogonal vectors case 2", check, 0.0, 1e-8);
+
+  // Orthogonal vectors test case 3
+  vgl_vector_3d<double> n3(0.0, 0.0, 1.0);
+  check = 0.0;
+  tr[0] = n3.orthogonal_vectors(0.0);
+  tr[1] = n3.orthogonal_vectors(0.25);
+  tr[2] = n3.orthogonal_vectors(0.5);
+  tr[3] = n3.orthogonal_vectors(0.75);
+  for (unsigned i = 0; i<4; ++i)
+  {
+    double d = dot_product<double>(n3, tr[i]);
+    check += d*d;
+    d = dot_product<double>(tr[i], tr[i])-1.0;
+    check += d*d;
+  }
+  TEST_NEAR("orthogonal vectors case 3", check, 0.0, 1e-8);
+
+  // Orthogonal vectors test case 4
+  vgl_vector_3d<double> n4(0.0, 1.0, 1.0); // NB input vector not normalized
+  check = 0.0;
+  tr[0] = n4.orthogonal_vectors(0.0);
+  tr[1] = n4.orthogonal_vectors(0.25);
+  tr[2] = n4.orthogonal_vectors(0.5);
+  tr[3] = n4.orthogonal_vectors(0.75);
+  for (unsigned i = 0; i<4; ++i)
+  {
+    double d = dot_product<double>(n4, tr[i]);
+    check += d*d;
+    d = dot_product<double>(tr[i], tr[i])-1.0;
+    check += d*d;
+  }
+  TEST_NEAR("orthogonal vectors case 4", check, 0.0, 1e-8);
+
+  // Orthogonal vectors test case 5
+  vgl_vector_3d<double> n5(1.0, 1.0, 0.0); // NB input vector not normalized
+  check = 0.0;
+  tr[0] = n5.orthogonal_vectors(0.0);
+  tr[1] = n5.orthogonal_vectors(0.25);
+  tr[2] = n5.orthogonal_vectors(0.5);
+  tr[3] = n5.orthogonal_vectors(0.75);
+  for (unsigned i = 0; i<4; ++i)
+  {
+    double d = dot_product<double>(n5, tr[i]);
+    check += d*d;
+    d = dot_product<double>(tr[i], tr[i])-1.0;
+    check += d*d;
+  }
+  TEST_NEAR("orthogonal vectors case 5", check, 0.0, 1e-8);
 
   vcl_stringstream is; is << "4.4 -5 7e1 10,11 , 12 (12 , 13,14 )";
   vgl_vector_3d<float> p; is >> p;
@@ -514,7 +553,9 @@ static void test_line_3d()
   TEST("concurrent", concurrent(l,l2), true);
   TEST("concurrent", coplanar(l,l2), true);
   p2 = vgl_intersection(l,l2);
-  TEST("intersection", p2, p1-dir*0.5);
+
+  bool intersection_ok = ( p2 == p1-dir*0.5 );
+  TEST("intersection", intersection_ok, true);
 
   vcl_stringstream is; is << "4 5 6  (7, 8, 9)";
   vgl_line_segment_3d<float> l_s; is >> l_s;
@@ -1055,26 +1096,16 @@ static void test_1d_basis()
 
 static void test_cartesian()
 {
-  vcl_cout << "--- test_vector_2d ---\n";
-  test_vector_2d();
-  vcl_cout << "--- test_vector_3d ---\n";
-  test_vector_3d();
-  vcl_cout << "--- test_point_2d ---\n";
-  test_point_2d();
-  vcl_cout << "--- test_point_3d ---\n";
-  test_point_3d();
-  vcl_cout << "--- test_line_2d ---\n";
-  test_line_2d();
-  vcl_cout << "--- test_line_3d ---\n";
-  test_line_3d();
-  vcl_cout << "--- test_plane_3d ---\n";
-  test_plane_3d();
-  vcl_cout << "--- test_box_2d ---\n";
-  test_box_2d();
-  vcl_cout << "--- test_box_3d ---\n";
-  test_box_3d();
-  vcl_cout << "-- Testing vgl_1d_basis --\n";
-  test_1d_basis();
+  vcl_cout << "--- test_vector_2d ---\n";     test_vector_2d();
+  vcl_cout << "--- test_vector_3d ---\n";     test_vector_3d();
+  vcl_cout << "--- test_point_2d ---\n";      test_point_2d();
+  vcl_cout << "--- test_point_3d ---\n";      test_point_3d();
+  vcl_cout << "--- test_line_2d ---\n";       test_line_2d();
+  vcl_cout << "--- test_line_3d ---\n";       test_line_3d();
+  vcl_cout << "--- test_plane_3d ---\n";      test_plane_3d();
+  vcl_cout << "--- test_box_2d ---\n";        test_box_2d();
+  vcl_cout << "--- test_box_3d ---\n";        test_box_3d();
+  vcl_cout << "-- Testing vgl_1d_basis --\n"; test_1d_basis();
 }
 
 TESTMAIN(test_cartesian);
