@@ -91,19 +91,9 @@ bool vgl_triangle_3d_test_inside(const vgl_point_3d<double>& i_pnt,
       return i_pnt == p1;
     }
 
-    vgl_line_segment_3d<double> test_line(p1,p2);
-    if (test_line.contains(i_pnt))
-      return true;
-
-    test_line.set(p2,p3);
-    if (test_line.contains(i_pnt))
-      return true;
-
-    test_line.set(p1,p3);
-    if (test_line.contains(i_pnt))
-      return true;
-
-    return false;
+    return vgl_line_segment_3d<double>(p1,p2).contains(i_pnt) ||
+           vgl_line_segment_3d<double>(p2,p3).contains(i_pnt) ||
+           vgl_line_segment_3d<double>(p1,p3).contains(i_pnt);
   }
 
   // use badouel's algorithm ( a barycentric method)
@@ -164,10 +154,8 @@ bool vgl_triangle_3d_test_inside(const vgl_point_3d<double>& i_pnt,
     alpha = (u0 - beta * u2) / u1;
   }
 
-  if (alpha < -sqrteps/*0*/ || (alpha + beta) > 1.0+sqrteps)
-    return false;
-
-  return true;
+  return alpha        >=    -sqrteps /*0*/
+      && alpha + beta <= 1.0+sqrteps;
 }
 
 //=======================================================================
@@ -192,7 +180,8 @@ bool vgl_triangle_3d_test_inside_simple(const vgl_point_3d<double>& i_pnt,
 }
 
 //! Are D and E on opposite sides of the plane that touches A, B, C
-//! \returns Co
+// \returns Skew if on same side, None if not, and Coplanar if D is on
+// plane ABC
 static vgl_triangle_3d_intersection_t same_side(
   const vgl_point_3d<double>& A,
   const vgl_point_3d<double>& B,
@@ -225,109 +214,6 @@ static vgl_triangle_3d_intersection_t same_side(
 }
 
 
-//=======================================================================
-//: Compute the intersection point between the line and triangle
-//  The triangle is represented by its vertices \a p1, \a p2, \a p3
-//  \return intersection type
-vgl_triangle_3d_intersection_t vgl_triangle_3d_line_intersection(
-  const vgl_line_3d_2_points<double>& line,
-  const vgl_point_3d<double>& p1,
-  const vgl_point_3d<double>& p2,
-  const vgl_point_3d<double>& p3,
-  vgl_point_3d<double>& i_pnt,
-  bool ignore_coplanar/*=false*/)
-{
-  vgl_point_3d<double> line_p1 = line.point1();
-  vgl_point_3d<double> line_p2 = line.point2();
-
-  // perform some degeneracy checks on the line and triangle
-  if (line_p1 == line_p2)
-  { //the line is degnerate - it has zero length
-    if (!ignore_coplanar && vgl_triangle_3d_test_inside(line_p1,p1,p2,p3))
-      return Coplanar;
-
-    return None;
-  }
-
-  if (collinear(p1,p2,p3))
-  { //the triangle is degenerate - it's points are collinear
-    if (p1==p2&&p2==p3&&p1==p3)
-    { //all its vertices are the same
-      return ignore_coplanar ? None : Coplanar;
-    }
-
-    if ( !ignore_coplanar && (
-        ( p1!=p2 && concurrent(vgl_line_3d_2_points<double>(p1,p2), line) &&
-          vgl_intersection(line,vgl_line_segment_3d<double>(p1,p2),i_pnt) ) ||
-        ( p2!=p3 && concurrent(vgl_line_3d_2_points<double>(p2,p3), line) &&
-          vgl_intersection(line,vgl_line_segment_3d<double>(p2,p3),i_pnt) ) ||
-        ( p1!=p3 && concurrent(vgl_line_3d_2_points<double>(p1,p3), line) &&
-          vgl_intersection(line,vgl_line_segment_3d<double>(p1,p3),i_pnt) ) ) )
-    {
-      return Coplanar;
-    }
-
-    return None;
-  }
-
-  vgl_triangle_3d_intersection_t rv;
-
-  rv = same_side(line.point1(), p1, p2, p3, line.point2());
-  if (rv == None) return None;
-
-  rv = same_side(line.point1(), p2, p3, p1, line.point2());
-  if (rv == None) return None;
-
-  rv = same_side(line.point1(), p3, p1, p2, line.point2());
-  if (rv == None) return None;
-
-  if (rv == Coplanar)
-  {
-    if (ignore_coplanar)
-      return None;
-    //coplanar line - uncommon case
-
-    //check each triangle edge.
-    //behaviour is to return the first found intersetion point
-    vgl_line_segment_3d<double> edge1(p1,p2);
-
-    vgl_point_3d<double> test_pt;
-    if (concurrent(vgl_line_3d_2_points<double>(p1,p2),line) &&
-        vgl_intersection(edge1,line,test_pt))
-    {
-      i_pnt = test_pt;
-      return Coplanar;
-    }
-    vgl_line_segment_3d<double> edge2(p1,p3);
-    if (concurrent(vgl_line_3d_2_points<double>(p1,p3),line) &&
-        vgl_intersection(edge2,line,test_pt))
-    {
-      i_pnt = test_pt;
-      return Coplanar;
-    }
-    vgl_line_segment_3d<double> edge3(p2,p3);
-    if (concurrent(vgl_line_3d_2_points<double>(p2,p3),line) &&
-        vgl_intersection(edge3,line,test_pt))
-    {
-      i_pnt = test_pt;
-      return Coplanar;
-    }
-
-    //special case of line completely contained within the triangle
-    if (vgl_triangle_3d_test_inside(line_p1, p1, p2, p3))
-    {
-      i_pnt.set(vgl_nan, vgl_nan, vgl_nan);
-      return Coplanar;
-    }
-
-    return None;
-  }
-
-  i_pnt = vgl_intersection(line,
-                           vgl_plane_3d<double>(p1, p2, p3) );
-  return Skew;
-}
-
 //=======================================================================
 //: Compute the intersection point between the line segment and triangle
 //  The triangle is represented by its vertices \a p1, \a p2, \a p3
@@ -1235,7 +1121,6 @@ vgl_triangle_3d_intersection_t vgl_triangle_3d_plane_intersection(
   if (vcl_fabs(p2_d) < sqrteps) p2_d = 0.0;
   if (vcl_fabs(p3_d) < sqrteps) p3_d = 0.0;
 
-  vgl_point_3d<double> i_pnt1, i_pnt2;
   vgl_line_3d_2_points<double> edge;
 
   if (p1_d*p2_d > 0 && p1_d*p3_d > 0) // all distances strictly same sign => no intersection
@@ -1245,66 +1130,64 @@ vgl_triangle_3d_intersection_t vgl_triangle_3d_plane_intersection(
   }
   else if (p1_d == 0 && p2_d == 0 && p3_d == 0) //triangle lies in plane
   {
-    i_pnt1.set(vgl_nan, vgl_nan, vgl_nan);
+    vgl_point_3d<double> i_pnt1; i_pnt1.set(vgl_nan, vgl_nan, vgl_nan);
     i_line.set(i_pnt1,i_pnt1);
     return Coplanar;
   }
   else if (p1_d*p2_d > 0) //p1, p2 on same side, p3 on the other
   {
     edge.set(p1,p3);
-    i_pnt1 = vgl_intersection(edge, i_plane);
+    vgl_point_3d<double> i_pnt1 = vgl_intersection(edge, i_plane);
     edge.set(p2,p3);
-    i_pnt2 = vgl_intersection(edge, i_plane);
+    vgl_point_3d<double> i_pnt2 = vgl_intersection(edge, i_plane);
+    i_line.set(i_pnt1,i_pnt2);
   }
   else if (p1_d*p3_d > 0) //p1, p3 on same side, p2 on the other
   {
     edge.set(p1,p2);
-    i_pnt1 = vgl_intersection(edge, i_plane);
+    vgl_point_3d<double> i_pnt1 = vgl_intersection(edge, i_plane);
     edge.set(p3,p2);
-    i_pnt2 = vgl_intersection(edge, i_plane);
+    vgl_point_3d<double> i_pnt2 = vgl_intersection(edge, i_plane);
+    i_line.set(i_pnt1,i_pnt2);
   }
   else if (p2_d*p3_d > 0) //p2, p3 on same side, p1 on the other
   {
     edge.set(p2,p1);
-    i_pnt1 = vgl_intersection(edge, i_plane);
+    vgl_point_3d<double> i_pnt1 = vgl_intersection(edge, i_plane);
     edge.set(p3,p1);
-    i_pnt2 = vgl_intersection(edge, i_plane);
+    vgl_point_3d<double> i_pnt2 = vgl_intersection(edge, i_plane);
+    i_line.set(i_pnt1,i_pnt2);
   }
   else if (p1_d == 0 && p2_d == 0) //edge p1,p2 in plane
   {
-    i_pnt1 = p1;
-    i_pnt2 = p2;
+    i_line.set(p1,p2);
   }
   else if (p1_d == 0 && p3_d == 0) //edge p1,p3 in plane
   {
-    i_pnt1 = p1;
-    i_pnt2 = p3;
+    i_line.set(p1,p3);
   }
   else if (p3_d == 0 && p2_d == 0) //edge p2,p3 in plane
   {
-    i_pnt1 = p2;
-    i_pnt2 = p3;
+    i_line.set(p2,p3);
   }
   else if (p1_d == 0) //just p1 in plane
   {
-    i_pnt1 = p1;
     edge.set(p3,p2);
-    i_pnt2 = vgl_intersection(edge, i_plane);
+    vgl_point_3d<double> i_pnt2 = vgl_intersection(edge, i_plane);
+    i_line.set(p1,i_pnt2);
   }
   else if (p2_d == 0) //just p2 in plane
   {
-    i_pnt1 = p2;
     edge.set(p3,p1);
-    i_pnt2 = vgl_intersection(edge, i_plane);
+    vgl_point_3d<double> i_pnt2 = vgl_intersection(edge, i_plane);
+    i_line.set(p2,i_pnt2);
   }
   else if (p3_d == 0) //just p3 in plane
   {
-    i_pnt1 = p3;
     edge.set(p2,p1);
-    i_pnt2 = vgl_intersection(edge, i_plane);
+    vgl_point_3d<double> i_pnt2 = vgl_intersection(edge, i_plane);
+    i_line.set(p3,i_pnt2);
   }
-
-  i_line.set(i_pnt1,i_pnt2);
   return Skew;
 }
 
@@ -1409,7 +1292,9 @@ bool vgl_triangle_3d_triangle_coplanar(
                             const vgl_point_3d<double>& b_p2,
                             const vgl_point_3d<double>& b_p3)
 {
-  return coplanar(a_p1,b_p1,b_p2,b_p3) && coplanar(a_p2,b_p1,b_p2,b_p3) && coplanar(a_p3,b_p1,b_p2,b_p3);
+  return coplanar(a_p1,b_p1,b_p2,b_p3)
+      && coplanar(a_p2,b_p1,b_p2,b_p3)
+      && coplanar(a_p3,b_p1,b_p2,b_p3);
 }
 
 //=======================================================================
