@@ -21,6 +21,7 @@
 //   26 Aug 2002 - Ian Scott - Started conversion to vil
 //    2 Oct 2002 - Peter Vanroose - replaced image24 tests by image3p
 //      Jun 2003 - Peter Vanroose - added viff, iris, mit tests for vil
+//   20 Oct 2009 - Gehua Yang     - added tests for wchar_t overloading functions on Windows
 // \endverbatim
 
 #include <vcl_cstring.h>
@@ -129,13 +130,13 @@ bool test_image_equal(char const* type_name,
 #endif
   vcl_cout << "istep()=" << image2.istep() << ", jstep()=" << image2.jstep()
            << ", planestep()=" << image2.planestep() << vcl_endl;
-  int i = image2.istep(); if (i<0) i = -i;
+  vcl_ptrdiff_t i = image2.istep(); if (i<0) i = -i;
   TEST("|istep| is either 1, or np or height or np*height", i==1||i==planes2||i==sizey2||i==planes2*sizey2, true);
-  int j = image2.jstep(); if (j<0) j = -j;
+  vcl_ptrdiff_t j = image2.jstep(); if (j<0) j = -j;
   TEST("|jstep| is either 1, or np or width or np*width",
        j==1||j==planes2||j==sizex2||j==4*((sizex2+3)/4)||j==planes2*sizex2||j==4*((planes2*sizex2+3)/4), true);
   // The "+3" is there to allow for "row word alignment", e.g. with the BMP format.
-  int p = image2.planestep(); if (p<0) p = -p;
+  vcl_ptrdiff_t p = image2.planestep(); if (p<0) p = -p;
   TEST("|planestep| is either 1 or width or height or width x height", p==1||p==sizex2||p==sizey2||p==sizex2*sizey2, true);
 
   if (100*sizex2+image2.jstep()<0 || 100*sizex2-image2.jstep()<0)
@@ -402,7 +403,7 @@ vil_image_view<vxl_byte> CreateTest8bitImage(int wd, int ht)
   vil_image_view<vxl_byte> image(wd, ht);
   for (int j = 0; j < ht; j++)
     for (int i = 0; i < wd; i++) {
-      image(i,j) = ((i-wd/2)*(j-ht/2)) & 0xff;
+      image(i,j) = vxl_byte(((i-wd/2)*(j-ht/2))&0xff);
     }
   return image;
 }
@@ -413,7 +414,7 @@ vil_image_view<vxl_uint_16> CreateTest16bitImage(int wd, int ht)
   vil_image_view<vxl_uint_16> image(wd, ht);
   for (int j = 0; j < ht; j++)
     for (int i = 0; i < wd; i++) {
-      image(i,j) = ((i-wd/2)*(j-ht/2)/16) & 0xffff;
+      image(i,j) = vxl_uint_16(((i-wd/2)*(j-ht/2)/16)&0xffff);
   }
   return image;
 }
@@ -435,9 +436,9 @@ vil_image_view<vil_rgb<vxl_byte> > CreateTest24bitImage(int wd, int ht)
   vil_image_view<vil_rgb<vxl_byte> > image(wd, ht);
   for (int i = 0; i < wd; i++)
     for (int j = 0; j < ht; j++)
-      image(i,j).r = i%(1<<8),
-      image(i,j).g = ((i-wd/2)*(j-ht/2)/16) % (1<<8),
-      image(i,j).b = ((j/3)%(1<<8));
+      image(i,j).r = vxl_byte(i%(1<<8)),
+      image(i,j).g = vxl_byte(((i-wd/2)*(j-ht/2)/16)%(1<<8)),
+      image(i,j).b = vxl_byte(((j/3)%(1<<8)));
   return image;
 }
 
@@ -447,9 +448,9 @@ vil_image_view<vxl_byte> CreateTest3planeImage(int wd, int ht)
   vil_image_view<vxl_byte> image( wd, ht, 3);
   for (int i = 0; i < wd; i++)
     for (int j = 0; j < ht; j++) {
-      image(i,j,0) = i%(1<<8);
-      image(i,j,1) = ((i-wd/2)*(j-ht/2)/16) % (1<<8);
-      image(i,j,2) = ((j/3)%(1<<8));
+      image(i,j,0) = vxl_byte(i%(1<<8));
+      image(i,j,1) = vxl_byte(((i-wd/2)*(j-ht/2)/16)%(1<<8));
+      image(i,j,2) = vxl_byte(((j/3)%(1<<8)));
     }
   return image;
 }
@@ -460,9 +461,9 @@ vil_image_view<vxl_byte> CreateTest3ComponentImage(int wd, int ht)
   vil_image_view<vxl_byte> image( wd, ht, 1, 3);
   for (int i = 0; i < wd; i++)
     for (int j = 0; j < ht; j++) {
-      image(i,j,0) = i%(1<<8);
-      image(i,j,1) = ((i-wd/2)*(j-ht/2)/16) % (1<<8);
-      image(i,j,2) = ((j/3)%(1<<8));
+      image(i,j,0) = vxl_byte(i%(1<<8));
+      image(i,j,1) = vxl_byte(((i-wd/2)*(j-ht/2)/16)%(1<<8));
+      image(i,j,2) = vxl_byte(((j/3)%(1<<8)));
     }
   return image;
 }
@@ -501,6 +502,21 @@ static void test_vil_save_image_resource()
 #endif
 }
 
+#if defined(VCL_WIN32) && VXL_USE_WIN_WCHAR_T
+static void test_vil_save_image_resource_wchar()
+{
+  vil_image_view<vxl_byte> view = CreateTest8bitImage(251, 153);
+  vil_image_resource_sptr mem = vil_new_image_resource_of_view(view);
+  const wchar_t* out_path = L"wchar_test_save_image_resource.pgm";
+  TEST("[wchar_t] Saving image resource",vil_save_image_resource(mem, out_path), true);
+  vil_image_view<vxl_byte> loaded_view = vil_load(out_path);
+  TEST("[wchar_t] Loaded correct image", vil_image_view_deep_equality(view, loaded_view),true);
+#if !LEAVE_IMAGES_BEHIND
+    _wunlink(out_path);
+#endif
+}
+#endif // defined(VCL_WIN32) && VXL_USE_WIN_WCHAR_T
+
 
 static void test_save_load_image()
 {
@@ -550,7 +566,9 @@ static void test_save_load_image()
 
   // VIFF image (Khoros 1.0)
 #if 1
-//vil_test_image_type("viff", image1, false); // boolean doesn't work (yet)
+#ifdef BOOLEAN_VIFF_WORKS // boolean doesn't work (yet)
+  vil_test_image_type("viff", image1, false);
+#endif
   vil_test_image_type("viff", image8, false);
   vil_test_image_type("viff", image16, false);
   vil_test_image_type("viff", image32, false);
@@ -562,6 +580,9 @@ static void test_save_load_image()
 
   // TIFF
 #if 1
+#ifdef BOOLEAN_TIFF_WORKS // boolean doesn't work (yet)
+  vil_test_image_type("tiff", image1);
+#endif
   vil_test_image_type("tiff", image8);
   vil_test_image_type("tiff", image3p);
   vil_test_image_type("tiff", image1);
@@ -590,7 +611,9 @@ static void test_save_load_image()
 
   // mit
 #if 1
-//vil_test_image_type("mit", image1, false); // boolean doesn't work (yet)
+#ifdef BOOLEAN_MIT_WORKS // boolean doesn't work (yet)
+  vil_test_image_type("mit", image1, false);
+#endif
   vil_test_image_type("mit", image8, false);
   vil_test_image_type("mit", image16, false);
   vil_test_image_type("mit", image32, false);
@@ -626,23 +649,42 @@ static void test_save_load_image()
     unsigned ni =30, nj=29;
     vil_image_view<vxl_byte> small_greyscale_image(ni,nj);
     for (unsigned j=0;j<nj;++j)
-      for (unsigned i=0;i<ni;++i) small_greyscale_image(i,j)=(i+j)*4;
+      for (unsigned i=0;i<ni;++i) small_greyscale_image(i,j) = vxl_byte((i+j)*4);
 #ifdef DEBUG
     vil_print_all(vcl_cout, small_greyscale_image);
 #endif
     vil_test_image_type("jpeg", small_greyscale_image, true, vxl_byte(5));
-    vcl_string out_path("test_save_load_jpeg.jpg");
-    TEST("Saving JPEG",vil_save(small_greyscale_image, out_path.c_str()),true);
+    {
+      vcl_string out_path("test_save_load_jpeg.jpg");
+      TEST("Saving JPEG",vil_save(small_greyscale_image, out_path.c_str()),true);
 
-    vil_image_view<vxl_byte> new_image = vil_load(out_path.c_str());
-    TEST("JPEG Size correct",new_image.ni()==ni && new_image.nj()==nj, true);
-    double sum2 = 0;
-    for (unsigned i=0;i<ni;++i)
-    { double d=double(small_greyscale_image(i,17))-new_image(i,17); sum2+=d*d; }
-    TEST_NEAR("Loaded image close to original",sum2,0.0,2*ni);
+      vil_image_view<vxl_byte> new_image = vil_load(out_path.c_str());
+      TEST("JPEG Size correct",new_image.ni()==ni && new_image.nj()==nj, true);
+      double sum2 = 0;
+      for (unsigned i=0;i<ni;++i)
+      { double d=double(small_greyscale_image(i,17))-new_image(i,17); sum2+=d*d; }
+      TEST_NEAR("Loaded image close to original",sum2,0.0,2*ni);
 #if !LEAVE_IMAGES_BEHIND
-    vpl_unlink(out_path.c_str());
+      vpl_unlink(out_path.c_str());
 #endif
+    }
+
+#if defined(VCL_WIN32) && VXL_USE_WIN_WCHAR_T
+    {
+      std::wstring out_wpath(L"wchar_test_save_load_jpeg.jpg");
+      TEST("[wchar_t] Saving JPEG",vil_save(small_greyscale_image, out_wpath.c_str()),true);
+
+      vil_image_view<vxl_byte> new_image = vil_load(out_wpath.c_str());
+      TEST("[wchar_t] JPEG Size correct",new_image.ni()==ni && new_image.nj()==nj, true);
+      double sum2 = 0;
+      for (unsigned i=0;i<ni;++i)
+      { double d=double(small_greyscale_image(i,17))-new_image(i,17); sum2+=d*d; }
+      TEST_NEAR("[wchar_t] Loaded image close to original",sum2,0.0,2*ni);
+#if !LEAVE_IMAGES_BEHIND
+      _wunlink(out_wpath.c_str());
+#endif
+    }
+#endif // defined(VCL_WIN32) && VXL_USE_WIN_WCHAR_T
   }
 #endif
 
@@ -650,6 +692,11 @@ static void test_save_load_image()
   // requires rnm support
 #if 1
   test_vil_save_image_resource();
+
+# if defined(VCL_WIN32) && VXL_USE_WIN_WCHAR_T
+  test_vil_save_image_resource_wchar();
+# endif // defined(VCL_WIN32) && VXL_USE_WIN_WCHAR_T
+
 #endif
 }
 
