@@ -788,6 +788,23 @@ vnl_matrix_fixed_mat_vec_mult(const vnl_matrix_fixed<T, M, N>& a,
   return out;
 }
 
+template <class T, unsigned M, unsigned N>
+inline
+vnl_vector_fixed<T, N>
+vnl_matrix_fixed_vec_mat_mult(const vnl_vector_fixed<T, M>& a,
+                              const vnl_matrix_fixed<T, M, N>& b)
+{
+  vnl_vector_fixed<T, N> out;
+  for (unsigned i = 0; i < N; ++i)
+  {
+    T accum = a(0) * b(0,i);
+    for (unsigned k = 1; k < M; ++k)
+      accum += a(k) * b(k,i);
+    out(i) = accum;
+  }
+  return out;
+}
+
 // see comment above
 template <class T, unsigned M, unsigned N, unsigned O>
 inline
@@ -811,22 +828,32 @@ vnl_matrix_fixed_mat_mat_mult(const vnl_matrix_fixed<T, M, N>& a,
 // The version for correct compilers
 
 //: Multiply  conformant vnl_matrix_fixed (M x N) and vector_fixed (N)
-// \relates vnl_vector_fixed
-// \relates vnl_matrix_fixed
+// \relatesalso vnl_vector_fixed
+// \relatesalso vnl_matrix_fixed
 template <class T, unsigned M, unsigned N>
 inline
 vnl_vector_fixed<T, M> operator*(const vnl_matrix_fixed<T, M, N>& a, const vnl_vector_fixed<T, N>& b)
 {
-  return vnl_matrix_fixed_mat_vec_mult(a,b);
+  return vnl_matrix_fixed_mat_vec_mult(a, b);
+}
+
+//: Multiply  conformant vector_fixed (M) and vnl_matrix_fixed (M x N)
+// \relatesalso vnl_vector_fixed
+// \relatesalso vnl_matrix_fixed
+template <class T, unsigned M, unsigned N>
+inline
+vnl_vector_fixed<T, N> operator*(const vnl_vector_fixed<T, M>& a, const vnl_matrix_fixed<T, M, N>& b)
+{
+  return vnl_matrix_fixed_vec_mat_mult(a, b);
 }
 
 //: Multiply two conformant vnl_matrix_fixed (M x N) times (N x O)
-// \relates vnl_matrix_fixed
+// \relatesalso vnl_matrix_fixed
 template <class T, unsigned M, unsigned N, unsigned O>
 inline
 vnl_matrix_fixed<T, M, O> operator*(const vnl_matrix_fixed<T, M, N>& a, const vnl_matrix_fixed<T, N, O>& b)
 {
-  return vnl_matrix_fixed_mat_mat_mult(a,b);
+  return vnl_matrix_fixed_mat_mat_mult(a, b);
 }
 #endif // VCL_VC_6
 
@@ -935,7 +962,7 @@ outer_product(vnl_vector_fixed<T,m> const& a, SecondFixedVector const& b)
 #else // no need for VC6 workaround for outer_product
 
 //:
-// \relates vnl_vector_fixed
+// \relatesalso vnl_vector_fixed
 template <class T, unsigned m, unsigned n>
 vnl_matrix_fixed<T,m,n> outer_product(vnl_vector_fixed<T,m> const& a, vnl_vector_fixed<T,n> const& b);
 
